@@ -23,16 +23,9 @@
 
 import os
 import re
-from six import print_, PY3
 import sys
 from utils import *
 
-if PY3:
-    do_open = lambda *args, **kwargs: open(*args, encoding='utf-8', **kwargs)
-else:
-    do_open = open
-
-
 from optparse import OptionParser
 
 try:
@@ -166,10 +159,10 @@ class BindingData:
             if not 'Makefile.am' in filenames:
                 # not a source dir
                 continue
-            makefile_am = do_open(os.path.join(base, 'Makefile.am')).read()
+            makefile_am = open(os.path.join(base, 'Makefile.am')).read()
             filenames = [x for x in filenames if x.endswith('.c') if x in makefile_am]
             for filename in filenames:
-                s = do_open(os.path.join(base, filename)).read()
+                s = open(os.path.join(base, filename)).read()
                 docstrings = regex.findall(s)
                 for d in docstrings:
                     docstring = '\n'.join([x[3:] for x in d.splitlines()])
@@ -247,7 +240,7 @@ class Function:
                 try:
                     arg = [x for x in self.args if x[1] == param.attrib.get('name')][0]
                 except IndexError:
-                    print_('W: no such param (%s) in function (%s)' % (
+                    print('W: no such param (%s) in function (%s)' % (
                             param.attrib.get('name'), self.name), file=sys.stderr)
                     continue
                 if param.attrib.get('optional') == 'true':
@@ -410,7 +403,7 @@ def parse_header(header_file):
     in_struct_private = False
     in_ifdef_zero = False
 
-    lines = do_open(header_file).readlines()
+    lines = open(header_file).readlines()
     i = 0
     while i < len(lines):
         line = lines[i]
@@ -435,7 +428,7 @@ def parse_header(header_file):
                 enum_name = line[2:].strip().strip(';')
                 binding.enums.append(enum_name)
             else:
-                m = re.match('\s*([a-zA-Z0-9_]+)', line)
+                m = re.match(r'\s*([a-zA-Z0-9_]+)', line)
                 if m:
                     binding.constants.append(('i', m.group(1)))
         elif line.startswith('#define'):
@@ -475,7 +468,7 @@ def parse_header(header_file):
                 if not in_struct.name in binding.structs_toskip:
                     binding.structs.append(in_struct)
                 else:
-                    print_('W: skipping structure %s due to overrides.xml' % in_struct.name, file=sys.stderr)
+                    print('W: skipping structure %s due to overrides.xml' % in_struct.name, file=sys.stderr)
                 in_struct = None
             elif '/*< public >*/' in line:
                 in_struct_private = False
@@ -489,13 +482,13 @@ def parse_header(header_file):
                 # TODO: Add parsing of OFTYPE
                 # Transform struct to typedef
                 # example: "struct _LassoAssertion" -> "LassoAssertion"
-                line = re.sub('\s+struct _', ' ', line)
-                member_match = re.match('\s+(\w+)\s+(\*?\w+)', line)
+                line = re.sub(r'\s+struct _', ' ', line)
+                member_match = re.match(r'\s+(\w+)\s+(\*?\w+)', line)
                 if member_match:
                     member_type, member_name = normalise_var(member_match.group(1), member_match.group(2))
                     field = (member_type, member_name, {})
                     if member_type == 'void*':
-                        print_('W: skipping field %s.%s' % (in_struct.name, member_name), file=sys.stderr)
+                        print('W: skipping field %s.%s' % (in_struct.name, member_name), file=sys.stderr)
                     else:
                         if is_glist(field) or is_hashtable(field):
                             found = re.search(r' of ([^*]*)', line)
@@ -544,13 +537,13 @@ def parse_header(header_file):
                                 type = clean_type(type)
                                 f.args.append(list((type, name, {})))
                             else:
-                                print_('failed to process:', arg, 'in line:', line, file=sys.stderr)
+                                print('failed to process:', arg, 'in line:', line, file=sys.stderr)
                                 f.skip = True
                         f.apply_overrides()
                         if not f.skip:
                             binding.functions.append(f)
                         else:
-                            print_('W: skipping function', f, file=sys.stderr)
+                            print('W: skipping function', f, file=sys.stderr)
 
         i += 1
 
