@@ -22,20 +22,19 @@ import os
 import os.path
 import sys
 import re
-from six import print_
 from utils import *
 
-class Output(object):
+class Output:
     def __init__(self, filename, indent = 4):
         self.fd = open(filename, 'w')
         self.indent_stack = [0]
         self.indent_size = indent
 
     def pn(self, s = ''):
-        print_((' ' * self.indent_stack[-1]) + s, file=self.fd)
+        print((' ' * self.indent_stack[-1]) + s, file=self.fd)
 
     def p(self, s = ''):
-        print_(s, file=self.fd, end="")
+        print(s, file=self.fd, end="")
 
     def close(self):
         self.fd.close()
@@ -95,8 +94,8 @@ class Binding:
         self.typemap.pn('''
 string_or_null\tT_STRING_OR_NULL
 string_non_null\tT_STRING_NON_NULL
-const gchar *\tT_PV
 gchar *\tT_PV
+const gchar *\tT_PV
 gboolean\tT_IV
 const LassoProvider *\tT_GOBJECT_WRAPPER
 xmlNode*\tT_XMLNODE
@@ -277,7 +276,7 @@ INCLUDE: LassoNode.xs
             try:
                 self.xs.pn(self.glist_type(func.return_arg))
             except:
-                print_('failed', func.return_arg, func, file=sys.stderr)
+                print('failed', func.return_arg, func, file=sys.stderr)
                 raise
         self.xs.p(name + '(')
         arg_list = []
@@ -376,12 +375,24 @@ INCLUDE: LassoNode.xs
             self.xs.pn('''   OUTPUT:
          RETVAL''')
             cleanup.append('lasso_unref(RETVAL);')
-        elif func.return_type and is_object(func.return_type) and not is_int(func.return_type, self.binding_data) and func.return_owner:
-            cleanup.append('lasso_unref(RETVAL);')
         elif is_rc(func.return_arg):
             if name == 'lasso_check_version':
                 cleanup.append('if (RETVAL != 1)')
             cleanup.append('gperl_lasso_error(RETVAL);')
+        elif func.return_type:
+            if is_transfer_full(func.return_arg, default=True):
+                if is_cstring(func.return_arg):
+                    cleanup.append('lasso_release_string(RETVAL);')
+                elif is_int(func.return_type, self.binding_data) or is_boolean(func.return_type):
+                    pass
+                elif is_xml_node(func.return_arg):
+                    pass
+                elif is_glist(func.return_arg):
+                    pass
+                elif is_object(func.return_arg):
+                    cleanup.append('lasso_unref(RETVAL);')
+                else:
+                    raise Exception('Unsupported caller owned return type %s' % ((repr(func.return_arg), func),))
         # Output cleanup code
         if cleanup:
             self.xs.pn('  CLEANUP:')
@@ -448,7 +459,7 @@ INCLUDE: LassoNode.xs
                 kind = "objects"
             else:
                 kind = "strings"
-            self.xs.pn('''
+            self.xs.pn(r'''
 HV*
 %(field)s(%(clss)s* obj, ...)
     PROTOTYPE:
@@ -587,12 +598,12 @@ HV*
                 self.generate_xs_function(func, prefix = prefix)
             for member in struct.members:
                 if arg_type(member) ==  'void*':
-                    print_('Skipping %s' % member)
+                    print('Skipping %s' % member)
                     continue
                 try:
                     self.generate_xs_getter_setter(struct, member)
                 except:
-                    print_('failed', struct, member)
+                    print('failed', struct, member)
                     raise
 
     def generate_wrapper(self):
