@@ -24,10 +24,13 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 
+import contextlib
 import unittest
+import queue
 import sys
 import os
 import logging
+import logging.handlers
 
 logging.basicConfig()
 
@@ -45,6 +48,23 @@ except NameError:
     dataDir = '%s/tests/data' % srcdir
 
 
+@contextlib.contextmanager
+def capture_logs():
+    root_logger = logging.getLogger()
+    handlers = root_logger.handlers[:]
+    class QueueLike(list):
+        def put_nowait(self, record):
+            self.append(record)
+
+    queue = QueueLike()
+    handler = logging.handlers.QueueHandler(queue)
+    root_logger.handlers = [handler]
+    try:
+        yield queue
+    finally:
+        root_logger.handlers = handlers
+
+
 class BindingTestCase(unittest.TestCase):
     def test01(self):
         """Create and delete nodes."""
@@ -254,10 +274,13 @@ class BindingTestCase(unittest.TestCase):
     def test07(self):
         '''Check reference counting'''
         s = lasso.Samlp2AuthnRequest()
-        cptr = s._cptr
+        # Starting with Python 3.14 some reference count changes
+        # are avoided.
+        # Creating a reference in a dict still increments refcount
+        data = {'cptr': s._cptr}
         a = sys.getrefcount(s._cptr)
         del(s)
-        b = sys.getrefcount(cptr)
+        b = sys.getrefcount(data['cptr'])
         self.assertEqual(b, a-1)
 
     def test08(self):
@@ -339,6 +362,12 @@ class BindingTestCase(unittest.TestCase):
         self.assertEqual(str(cm.exception),
                          '<lasso.XmlSchemaInvalidFragmentError(17): An XML tree does not respect at least an XML schema of its namespaces.>')
 
+    def test_provider_get_key_encryption_method(self):
+        # check getKeyEncryptionMethod is a Provider method #101250
+        with self.assertRaises(AttributeError):
+            getattr(lasso, 'providerGetKeyEncryptionMethod')
+        getattr(lasso.Provider, 'getKeyEncryptionMethod')
+
     def test_set_list_of_strings(self):
         node = lasso.Samlp2RequestedAuthnContext()
         with self.assertRaises(TypeError, msg='value should be a tuple of strings'):
@@ -353,7 +382,118 @@ class BindingTestCase(unittest.TestCase):
         with self.assertRaises(TypeError, msg='value should be a tuple of PyGobject'):
             node.attributeValue = value
 
-bindingSuite = unittest.makeSuite(BindingTestCase, 'test')
+    def test_saml1_soap_attributes(self):
+        # Test AttributeStatement AttributeValue text extraction
+        # Example SAML 1.1 validation response taken from
+        # https://github.com/apereo/cas/blob/master/docs/cas-server-documentation/protocol/CAS-Protocol-Specification.md
+        soap_content = """ 
+<SOAP-ENV:Envelope xmlns:SOAP-ENV=\"http://schemas.xmlsoap.org/soap/envelope/\">
+  <SOAP-ENV:Header />
+  <SOAP-ENV:Body>
+    <Response xmlns=\"urn:oasis:names:tc:SAML:1.0:protocol\" xmlns:saml=\"urn:oasis:names:tc:SAML:1.0:assertion\"
+    xmlns:samlp=\"urn:oasis:names:tc:SAML:1.0:protocol\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\"
+    xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" IssueInstant=\"2008-12-10T14:12:14.817Z\"
+    MajorVersion=\"1\" MinorVersion=\"1\" Recipient=\"https://eiger.iad.vt.edu/dat/home.do\"
+    ResponseID=\"_5c94b5431c540365e5a70b2874b75996\">
+      <Status>
+        <StatusCode Value=\"samlp:Success\">
+        </StatusCode>
+      </Status>
+      <Assertion xmlns=\"urn:oasis:names:tc:SAML:1.0:assertion\" AssertionID=\"_e5c23ff7a3889e12fa01802a47331653\"
+      IssueInstant=\"2008-12-10T14:12:14.817Z\" Issuer=\"localhost\" MajorVersion=\"1\"
+      MinorVersion=\"1\">
+        <Conditions NotBefore=\"2008-12-10T14:12:14.817Z\" NotOnOrAfter=\"2008-12-10T14:12:44.817Z\">
+          <AudienceRestrictionCondition>
+            <Audience>
+              https://some-service.example.com/app/
+            </Audience>
+          </AudienceRestrictionCondition>
+        </Conditions>
+        <AttributeStatement>
+          <Subject>
+            <NameIdentifier>johnq</NameIdentifier>
+            <SubjectConfirmation>
+              <ConfirmationMethod>
+                urn:oasis:names:tc:SAML:1.0:cm:artifact
+              </ConfirmationMethod>
+            </SubjectConfirmation>
+          </Subject>
+          <Attribute AttributeName=\"uid\" AttributeNamespace=\"http://www.ja-sig.org/products/cas/\">
+            <AttributeValue>12345</AttributeValue>
+          </Attribute>
+          <Attribute AttributeName=\"groupMembership\" AttributeNamespace=\"http://www.ja-sig.org/products/cas/\">
+            <AttributeValue>
+              uugid=middleware.staff,ou=Groups,dc=vt,dc=edu
+            </AttributeValue>
+          </Attribute>
+          <Attribute AttributeName=\"eduPersonAffiliation\" AttributeNamespace=\"http://www.ja-sig.org/products/cas/\">
+            <AttributeValue>staff</AttributeValue>
+          </Attribute>
+          <Attribute AttributeName=\"accountState\" AttributeNamespace=\"http://www.ja-sig.org/products/cas/\">
+            <AttributeValue>ACTIVE</AttributeValue>
+          </Attribute>
+        </AttributeStatement>
+        <AuthenticationStatement AuthenticationInstant=\"2008-12-10T14:12:14.741Z\"
+        AuthenticationMethod=\"urn:oasis:names:tc:SAML:1.0:am:password\">
+          <Subject>
+            <NameIdentifier>johnq</NameIdentifier>
+            <SubjectConfirmation>
+              <ConfirmationMethod>
+                urn:oasis:names:tc:SAML:1.0:cm:artifact
+              </ConfirmationMethod>
+            </SubjectConfirmation>
+          </Subject>
+        </AuthenticationStatement>
+      </Assertion>
+    </Response>
+  </SOAP-ENV:Body>
+</SOAP-ENV:Envelope>
+"""
+        expt_attrs = {'uid': '12345',
+                      'groupMembership': 'uugid=middleware.staff,ou=Groups,dc=vt,dc=edu',
+                      'eduPersonAffiliation': 'staff',
+                      'accountState': 'ACTIVE'}
+        node = lasso.Node.newFromSoap(soap_content)
+        assert len(node.assertion) == 1
+        assertion = node.assertion[0]
+        for attribute in assertion.attributeStatement.attribute:
+            attr_name = attribute.attributeName
+            with self.subTest(name=attr_name):
+                self.assertEqual(len(attribute.attributeValue), 1)
+                value = attribute.attributeValue[0]
+                self.assertEqual(len(value.any), 1)
+                content = value.any[0].content
+                self.assertIn(attr_name, expt_attrs)
+                self.assertEqual(expt_attrs[attr_name], content.strip())
+
+    def test_unexpected_text_content(self):
+        content = '''<Conditions xmlns=\"urn:oasis:names:tc:SAML:1.0:assertion\" NotBefore=\"2008-12-10T14:12:14.817Z\" NotOnOrAfter=\"2008-12-10T14:12:44.817Z\">
+          <AudienceRestrictionCondition>
+            <Audience>
+              https://some-service.example.com/app/
+            </Audience>
+          </AudienceRestrictionCondition>
+        </Conditions>'''
+        node = lasso.Node.newFromXmlNode(content)
+        assert node
+
+        content = '''<Conditions xmlns=\"urn:oasis:names:tc:SAML:1.0:assertion\" NotBefore=\"2008-12-10T14:12:14.817Z\" NotOnOrAfter=\"2008-12-10T14:12:44.817Z\">
+          XXXX unexpected XXXX
+          <AudienceRestrictionCondition>
+            <Audience>
+              https://some-service.example.com/app/
+            </Audience>
+          </AudienceRestrictionCondition>
+        </Conditions>'''
+        with capture_logs() as records:
+            node = lasso.Node.newFromXmlNode(content)
+        assert not node
+        assert records
+        assert len(records) == 2, f'{records} not of length 2'
+        assert 'was not expected' in str(records[0])
+        assert 'node initialization failed' in str(records[1])
+
+bindingSuite = unittest.defaultTestLoader.loadTestsFromTestCase(BindingTestCase)
 
 allTests = unittest.TestSuite((bindingSuite, ))
 
