@@ -24,6 +24,7 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 
+import base64
 import os
 import unittest
 import sys
@@ -330,6 +331,12 @@ class LoginTestCase(unittest.TestCase):
             sp_login.setSignatureVerifyHint(lasso.PROFILE_SIGNATURE_VERIFY_HINT_FORCE)
             sp_login.processAuthnResponseMsg(idp_login.msgBody)
             sp_login.acceptSso()
+
+            if key_encryption_method:
+                expected_key_encryption_method = key_encryption_method
+            else:
+                expected_key_encryption_method = lasso.getDefaultKeyEncryptionMethod()
+            assert provider.getKeyEncryptionMethod() == expected_key_encryption_method
             return sp_login.response.debug()
 
         os.environ['LASSO_DEFAULT_KEY_ENCRYPTION_METHOD'] = 'rsa-pkcs1'
@@ -356,6 +363,59 @@ class LoginTestCase(unittest.TestCase):
         assert 'xmlenc#rsa-1_5' not in run(key_encryption_method=lasso.KEY_ENCRYPTION_METHOD_OAEP)
         assert 'xmlenc#rsa-oaep-mgf1p' in run(key_encryption_method=lasso.KEY_ENCRYPTION_METHOD_OAEP)
 
+    def test_09(self):
+        '''Login test between SP and IdP with encrypted private keys'''
+        sp_server = server('sp7-saml2', lasso.PROVIDER_ROLE_IDP, 'idp7-saml2')
+        idp_server = server('idp7-saml2', lasso.PROVIDER_ROLE_SP, 'sp7-saml2')
+
+        sp_login = lasso.Login(sp_server)
+        sp_login.initAuthnRequest()
+        sp_login.request.protocolBinding = lasso.SAML2_METADATA_BINDING_POST
+        sp_login.buildAuthnRequestMsg()
+        idp_login = lasso.Login(idp_server)
+        idp_login.setSignatureVerifyHint(lasso.PROFILE_SIGNATURE_VERIFY_HINT_FORCE)
+        idp_login.processAuthnRequestMsg(sp_login.msgUrl.split('?')[1])
+        idp_login.validateRequestMsg(True, True)
+        idp_login.buildAssertion("None", "None", "None", "None", "None")
+        content = lasso.MiscTextNode.newWithString("john.doe")
+        content.textChild = True
+        idp_login.assertion.addAttributeWithNode('login', lasso.SAML2_ATTRIBUTE_NAME_FORMAT_BASIC, content)
+        idp_login.buildAuthnResponseMsg()
+        sp_login.setSignatureVerifyHint(lasso.PROFILE_SIGNATURE_VERIFY_HINT_FORCE)
+        # insert comment inside NameID
+        msg = base64.b64decode(idp_login.msgBody).decode()
+        msg = msg.replace(idp_login.assertion.subject.nameId.content, idp_login.assertion.subject.nameId.content[:10] + '<!-- coin -->' + idp_login.assertion.subject.nameId.content[10:])
+        msg = msg.replace('john.doe', 'john.<!-- coin -->doe')
+        msg = base64.b64encode(msg.encode())
+        sp_login.processAuthnResponseMsg(msg.decode())
+        sp_login.acceptSso()
+        assert sp_login.assertion.subject.nameId.content == idp_login.assertion.subject.nameId.content
+        nodes = sp_login.assertion.attributeStatement[0].attribute[0].attributeValue[0].any
+        assert all(node.textChild for node in nodes)
+        assert ''.join(node.content for node in nodes) == 'john.doe'
+
+    def test_10(self):
+        '''Login test between SP and IdP with encrypted private keys'''
+        sp_server = server('sp7-saml2', lasso.PROVIDER_ROLE_IDP, 'idp7-saml2')
+        idp_server = server('idp7-saml2', lasso.PROVIDER_ROLE_SP, 'sp7-saml2')
+
+        sp_login = lasso.Login(sp_server)
+        sp_login.initAuthnRequest()
+        sp_login.request.protocolBinding = lasso.SAML2_METADATA_BINDING_POST
+        sp_login.buildAuthnRequestMsg()
+        idp_login = lasso.Login(idp_server)
+        idp_login.setSignatureVerifyHint(lasso.PROFILE_SIGNATURE_VERIFY_HINT_FORCE)
+        idp_login.processAuthnRequestMsg(sp_login.msgUrl.split('?')[1])
+        idp_login.validateRequestMsg(True, True)
+        idp_login.buildAssertion("None", "None", "None", "None", "None")
+        idp_login.buildAuthnResponseMsg()
+        sp_login.setSignatureVerifyHint(lasso.PROFILE_SIGNATURE_VERIFY_HINT_FORCE)
+        # insert comment inside NameID
+        msg = base64.b64encode(base64.b64decode(idp_login.msgBody).decode().replace(idp_login.assertion.subject.nameId.content, '<![CDATA[%s]]>' % idp_login.assertion.subject.nameId.content).replace('NameID>', 'NameID><![CDATA[]]>').encode())
+        sp_login.processAuthnResponseMsg(msg.decode())
+        sp_login.acceptSso()
+        assert sp_login.assertion.subject.nameId.content == idp_login.assertion.subject.nameId.content
+
 
 class LogoutTestCase(unittest.TestCase):
     def test01(self):
@@ -543,12 +603,12 @@ class AttributeAuthorityTestCase(unittest.TestCase):
         assert aq.response.assertion[0].attributeStatement[0].attribute[0]
         assert aq.response.assertion[0].attributeStatement[0].attribute[0].attributeValue[0]
 
-serverSuite = unittest.makeSuite(ServerTestCase, 'test')
-loginSuite = unittest.makeSuite(LoginTestCase, 'test')
-logoutSuite = unittest.makeSuite(LogoutTestCase, 'test')
-defederationSuite = unittest.makeSuite(DefederationTestCase, 'test')
-identitySuite = unittest.makeSuite(IdentityTestCase, 'test')
-attributeSuite = unittest.makeSuite(AttributeAuthorityTestCase, 'test')
+serverSuite = unittest.defaultTestLoader.loadTestsFromTestCase(ServerTestCase)
+loginSuite = unittest.defaultTestLoader.loadTestsFromTestCase(LoginTestCase)
+logoutSuite = unittest.defaultTestLoader.loadTestsFromTestCase(LogoutTestCase)
+defederationSuite = unittest.defaultTestLoader.loadTestsFromTestCase(DefederationTestCase)
+identitySuite = unittest.defaultTestLoader.loadTestsFromTestCase(IdentityTestCase)
+attributeSuite = unittest.defaultTestLoader.loadTestsFromTestCase(AttributeAuthorityTestCase)
 
 allTests = unittest.TestSuite((serverSuite, loginSuite, logoutSuite, defederationSuite,
                                identitySuite, attributeSuite))
