@@ -1,5 +1,4 @@
 #! /usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # $Id: tests.py 3425 2007-10-10 09:31:03Z dlaniel $
 #
@@ -31,7 +30,6 @@ import os
 import sys
 import time
 import unittest
-from six import print_
 
 from XmlTestRunner import XmlTestRunner
 
@@ -61,10 +59,10 @@ parser.add_option(
 __builtin__.__dict__['dataDir'] = os.path.join(options.srcDir, '../../../tests/data')
 
 if options.xmlMode:
-    print_('<?xml version="1.0"?>')
-    print_('<testsuites xmlns="http://check.sourceforge.net/ns">')
-    print_('  <title>Python Bindings</title>')
-    print_('  <datetime>%s</datetime>' % time.strftime('%Y-%m-%d %H:%M:%S', time.localtime()))
+    print('<?xml version="1.0"?>')
+    print('<testsuites xmlns="http://check.sourceforge.net/ns">')
+    print('  <title>Python Bindings</title>')
+    print('  <datetime>%s</datetime>' % time.strftime('%Y-%m-%d %H:%M:%S', time.localtime()))
 
 success = True
 for testSuite in testSuites:
@@ -75,7 +73,7 @@ for testSuite in testSuites:
         if fp:
             fp.close()
     if not module:
-        print_('Unable to load test suite:', testSuite, file=sys.stderr)
+        print('Unable to load test suite:', testSuite, file=sys.stderr)
         continue
 
     if module.__doc__:
@@ -88,13 +86,13 @@ for testSuite in testSuites:
     else:
         runner = unittest.TextTestRunner(verbosity=2)
         print
-        print_('-' * len(doc))
-        print_(doc)
-        print_('-' * len(doc))
+        print('-' * len(doc))
+        print(doc)
+        print('-' * len(doc))
     result = runner.run(module.allTests)
     success = success and result.wasSuccessful()
 
 if options.xmlMode:
-    print_('</testsuites>')
+    print('</testsuites>')
 
 sys.exit(not success)
