@@ -100,7 +100,7 @@ G_GNUC_UNUSED static PyObject *get_list_of_strings(const GList *a_list);
 G_GNUC_UNUSED static PyObject *get_list_of_xml_nodes(const GList *a_list);
 G_GNUC_UNUSED static PyObject *get_list_of_pygobject(const GList *a_list);
 G_GNUC_UNUSED static gboolean valid_seq(PyObject *seq);
-G_GNUC_UNUSED static void free_list(GList **a_list, GFunc free_help);
+G_GNUC_UNUSED static void free_list(GList **a_list, GFreeFunc free_help);
 G_GNUC_UNUSED static time_t* get_time_t(PyObject *time);
 
 typedef struct {
@@ -223,9 +223,14 @@ valid_seq(PyObject *seq) {
 }
 
 static void
-free_list(GList **a_list, GFunc free_help) {
+free_list(GList **a_list, GFreeFunc free_help) {
+	GList *ptr = *a_list;
+
+	while (ptr) {
+		free_help(ptr->data);
+		ptr = ptr->next;
+	}
 	if (*a_list) {
-		g_list_foreach(*a_list, free_help, NULL);
 		g_list_free(*a_list);
 	}
 }
@@ -351,11 +356,11 @@ set_list_of_strings(GList **a_list, PyObject *seq) {
 		list = g_list_append(list, g_strdup(astr));
 		PyStringFree(astr);
 	}
-	free_list(a_list, (GFunc)g_free);
+	free_list(a_list, g_free);
 	*a_list = list;
 	return 1;
 failure:
-	free_list(&list, (GFunc)g_free);
+	free_list(&list, g_free);
 	return 0;
 }
 
@@ -391,11 +396,11 @@ set_list_of_xml_nodes(GList **a_list, PyObject *seq) {
 		}
 		list = g_list_append(list, item_node);
 	}
-	free_list(a_list, (GFunc)xmlFreeNode);
+	free_list(a_list, (GFreeFunc)xmlFreeNode);
 	*a_list = list;
 	return 1;
 failure:
-	free_list(&list, (GFunc)xmlFreeNode);
+	free_list(&list, (GFreeFunc)xmlFreeNode);
 	return 0;
 }
 
@@ -426,11 +431,11 @@ set_list_of_pygobject(GList **a_list, PyObject *seq) {
 		gobject = g_object_ref(((PyGObjectPtr*)item)->obj);
 		list = g_list_append(list, gobject);
 	}
-	free_list(a_list, (GFunc)g_object_unref);
+	free_list(a_list, g_object_unref);
 	*a_list = list;
 	return 1;
 failure:
-	free_list(&list, (GFunc)g_object_unref);
+	free_list(&list, g_object_unref);
 	return 0;
 }
 
