@@ -27,7 +27,7 @@ lasso_string_fragment_to_xmlnode(const char *fragment, int size) {
 	}
 
 	/* single node case, with preceding or following spaces */
-	doc = xmlReadMemory(fragment, size, NULL, NULL, XML_PARSE_NONET);
+	doc = xmlReadMemory(fragment, size, NULL, NULL, XML_PARSE_NONET | XML_PARSE_NOCDATA);
 	if (doc) {
 		node = xmlDocGetRootElement(doc);
 		if (node != NULL) {
