@@ -4,14 +4,14 @@ import glob
 import re
 import sys
 import os
-from six import print_, StringIO
+from io import StringIO
 
 srcdir = sys.argv[1]
 
 messages = dict()
 description = ''
 
-with open('%s/errors.h' % srcdir,'r') as f:
+with open('%s/errors.h' % srcdir) as f:
     for line in f:
         m = re.match(r'^ \* LASSO.*ERROR', line)
         if m:
@@ -30,13 +30,13 @@ with open('%s/errors.h' % srcdir,'r') as f:
             if m:
                 messages[m.group(1)] = m.group(1)
 
-with open('%s/errors.c.in' % srcdir,'r') as f:
+with open('%s/errors.c.in' % srcdir) as f:
     for line in f:
         if '@ERROR_CASES@' in line:
             keys = sorted(messages.keys())
             for k in keys:
-                print_('		case %s:\n'
+                print('		case %s:\n'
                        '			return "%s";' %
                        (k,messages[k].rstrip('\n')))
         else:
-            print_(line, end="")
+            print(line, end="")
