@@ -18,8 +18,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __LASSO_EXPORT_H__
@@ -29,7 +28,7 @@
 extern "C" {
 #endif /* __cplusplus */
 
-#include "./ctypes.h"
+#include "ctypes.h"
 
 /* Now, the export orgy begins. The following we must do for the
  * Windows platform with MSVC compiler. */
