@@ -4,7 +4,6 @@ import io
 import glob
 import re
 import sys
-import six
 
 if len(sys.argv) == 2:
     srcdir = sys.argv[1]
@@ -17,8 +16,8 @@ symbols = []
 for header_file in glob.glob('%s/*/*.h' % srcdir) + glob.glob('%s/*.h' % srcdir) + \
         glob.glob('%s/*/*/*.h' % srcdir):
     assert not ('/id-wsf/' in header_file or '/id-wsf-2.0' in header_file)
-    symbols.extend(regex.findall(io.open(header_file, encoding='utf-8').read().replace('\\\n', '')))
+    symbols.extend(regex.findall(open(header_file, encoding='utf-8').read().replace('\\\n', '')))
 
 for s in symbols:
-    six.print_(s)
+    print(s)
 
