@@ -98,7 +98,8 @@ struct _LassoLogin {
 	gchar *nameIDPolicy;
 	LassoHttpMethod http_method;
 
-	LassoLoginPrivate *private_data;
+	/* keeping it to preserve struct size */
+	LassoLoginPrivate *private_data __attribute__ ((deprecated));
 };
 
 struct _LassoLoginClass {
