@@ -39,6 +39,11 @@ struct _LassoLoginPrivate
 	char *request_id;
 };
 
+LassoSaml2Assertion *lasso_login_get_saml2_assertion(LassoLogin *login);
+void lasso_login_set_saml2_assertion(LassoLogin *login, LassoSaml2Assertion *assertion);
+const char *lasso_login_get_request_id(LassoLogin *login);
+void lasso_login_set_request_id(LassoLogin *login, char *request_id);
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
