@@ -378,7 +378,7 @@ lasso_logout_build_response_msg(LassoLogout *logout)
 	profile = &logout->parent;
 	lasso_profile_clean_msg_info(profile);
 
-	if (! profile->private_data || ! logout->private_data) {
+	if (! lasso_profile_is_init(profile) || ! logout->private_data) {
 		return LASSO_PARAM_ERROR_NON_INITIALIZED_OBJECT;
 	}
 
