@@ -52,6 +52,8 @@
 
 #include <stdio.h>
 
+G_DEFINE_TYPE_WITH_PRIVATE(LassoProfile, lasso_profile, LASSO_TYPE_NODE);
+
 /*****************************************************************************/
 /* public functions                                                          */
 /*****************************************************************************/
@@ -434,7 +436,8 @@ lasso_profile_set_session_from_dump(LassoProfile *profile, const gchar *dump)
 char*
 lasso_profile_get_artifact(LassoProfile *profile)
 {
-	return g_strdup(profile->private_data->artifact);
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+	return g_strdup(private_data->artifact);
 }
 
 /**
@@ -448,7 +451,8 @@ lasso_profile_get_artifact(LassoProfile *profile)
 char*
 lasso_profile_get_artifact_message(LassoProfile *profile)
 {
-	return g_strdup(profile->private_data->artifact_message);
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+	return g_strdup(private_data->artifact_message);
 }
 
 /**
@@ -467,7 +471,8 @@ lasso_profile_set_artifact_message(LassoProfile *profile, const char *message)
 			"LassoProfile object: %p", profile);
 		return;
 	}
-	lasso_assign_string(profile->private_data->artifact_message, message);
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+	lasso_assign_string(private_data->artifact_message, message);
 }
 
 /**
@@ -508,7 +513,8 @@ lasso_profile_get_server(LassoProfile *profile)
 char*
 lasso_profile_get_message_id(LassoProfile *profile)
 {
-	return g_strdup(profile->private_data->message_id);
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+	return g_strdup(private_data->message_id);
 }
 
 /**
@@ -527,7 +533,8 @@ lasso_profile_set_message_id(LassoProfile *profile, const char *message_id)
 			"LassoProfile object: %p", profile);
 		return;
 	}
-	lasso_assign_string(profile->private_data->message_id, message_id);
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+	lasso_assign_string(private_data->message_id, message_id);
 }
 
 /**
@@ -542,7 +549,8 @@ lasso_profile_set_message_id(LassoProfile *profile, const char *message_id)
 LassoNode*
 lasso_profile_get_idp_list(LassoProfile *profile)
 {
-	return profile->private_data->idp_list;
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+	return private_data->idp_list;
 }
 
 /**
@@ -562,7 +570,8 @@ lasso_profile_set_idp_list(LassoProfile *profile, const LassoNode *idp_list)
 			"LassoProfile object: %p", profile);
 		return;
 	}
-	lasso_assign_gobject(profile->private_data->idp_list, idp_list);
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+	lasso_assign_gobject(private_data->idp_list, idp_list);
 }
 
 /*****************************************************************************/
@@ -603,9 +612,10 @@ static LassoNodeClass *parent_class = NULL;
 void
 lasso_profile_set_signature_hint(LassoProfile *profile, LassoProfileSignatureHint signature_hint)
 {
-	if (! LASSO_IS_PROFILE(profile) || ! profile->private_data)
-		return;
-	profile->private_data->signature_hint = signature_hint;
+	if (! LASSO_IS_PROFILE(profile)) { return; }
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+	if (! private_data) { return; }
+	private_data->signature_hint = signature_hint;
 }
 
 /**
@@ -620,15 +630,22 @@ LassoProfileSignatureHint
 lasso_profile_get_signature_hint(LassoProfile *profile)
 {
 	LassoProfileSignatureVerifyHint signature_verify_hint;
-	if (! LASSO_IS_PROFILE(profile) || ! profile->private_data)
+	if (! LASSO_IS_PROFILE(profile))
+	{
 		return LASSO_PROFILE_SIGNATURE_HINT_MAYBE;
-	signature_verify_hint = profile->private_data->signature_verify_hint;
+	}
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+	if (! private_data)
+	{
+		return LASSO_PROFILE_SIGNATURE_HINT_MAYBE;
+	}
+	signature_verify_hint = private_data->signature_verify_hint;
 	if (signature_verify_hint >= LASSO_PROFILE_SIGNATURE_VERIFY_HINT_LAST) {
 		message(G_LOG_LEVEL_WARNING, "%u is an invalid signature verify hint",
 				signature_verify_hint);
 		return LASSO_PROFILE_SIGNATURE_HINT_MAYBE;
 	}
-	return profile->private_data->signature_hint;
+	return private_data->signature_hint;
 }
 
 /**
@@ -644,14 +661,15 @@ void
 lasso_profile_set_signature_verify_hint(LassoProfile *profile,
 		LassoProfileSignatureVerifyHint signature_verify_hint)
 {
-	if (! LASSO_IS_PROFILE(profile) || ! profile->private_data)
-		return;
+	if (! LASSO_IS_PROFILE(profile)) { return; }
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+	if (! private_data) { return; }
 	if (signature_verify_hint >= LASSO_PROFILE_SIGNATURE_VERIFY_HINT_LAST) {
 		message(G_LOG_LEVEL_WARNING, "%i is an invalid argument for " __FUNCTION__,
 				signature_verify_hint);
 		return;
 	}
-	profile->private_data->signature_verify_hint = signature_verify_hint;
+	private_data->signature_verify_hint = signature_verify_hint;
 }
 
 /**
@@ -666,9 +684,16 @@ lasso_profile_set_signature_verify_hint(LassoProfile *profile,
 LassoProfileSignatureVerifyHint
 lasso_profile_get_signature_verify_hint(LassoProfile *profile)
 {
-	if (! LASSO_IS_PROFILE(profile) || ! profile->private_data)
+	if (! LASSO_IS_PROFILE(profile))
+	{
 		return LASSO_PROFILE_SIGNATURE_VERIFY_HINT_MAYBE;
-	return profile->private_data->signature_verify_hint;
+	}
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+	if (! private_data)
+	{
+		return LASSO_PROFILE_SIGNATURE_VERIFY_HINT_MAYBE;
+	}
+	return private_data->signature_verify_hint;
 }
 
 
@@ -899,11 +924,12 @@ static void
 dispose(GObject *object)
 {
 	LassoProfile *profile = LASSO_PROFILE(object);
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
 
-	if (profile->private_data->dispose_has_run) {
+	if (private_data->dispose_has_run) {
 		return;
 	}
-	profile->private_data->dispose_has_run = TRUE;
+	private_data->dispose_has_run = TRUE;
 
 
 	lasso_mem_debug("LassoProfile", "Server", profile->server);
@@ -915,13 +941,13 @@ dispose(GObject *object)
 	lasso_mem_debug("LassoProfile", "Session", profile->session);
 	lasso_release_gobject(profile->session);
 
-	lasso_release_string(profile->private_data->artifact);
-	lasso_release_string(profile->private_data->artifact_message);
+	lasso_release_string(private_data->artifact);
+	lasso_release_string(private_data->artifact_message);
 
 	G_OBJECT_CLASS(parent_class)->dispose(G_OBJECT(profile));
 
-	lasso_release_gobject(profile->private_data->idp_list);
-	lasso_release_string(profile->private_data->message_id);
+	lasso_release_gobject(private_data->idp_list);
+	lasso_release_string(private_data->message_id);
 }
 
 /*****************************************************************************/
@@ -929,15 +955,20 @@ dispose(GObject *object)
 /*****************************************************************************/
 
 static void
-instance_init(LassoProfile *profile, G_GNUC_UNUSED void *unused)
+lasso_profile_init(LassoProfile *profile)
 {
-	profile->private_data = LASSO_PROFILE_GET_PRIVATE(profile);
-	profile->private_data->dispose_has_run = FALSE;
-	profile->private_data->artifact = NULL;
-	profile->private_data->artifact_message = NULL;
-	profile->private_data->signature_hint = LASSO_PROFILE_SIGNATURE_HINT_MAYBE;
-	profile->private_data->message_id = NULL;
-	profile->private_data->idp_list = NULL;
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+	profile->private_data = private_data;
+#pragma GCC diagnostic pop
+
+	private_data->dispose_has_run = FALSE;
+	private_data->artifact = NULL;
+	private_data->artifact_message = NULL;
+	private_data->signature_hint = LASSO_PROFILE_SIGNATURE_HINT_MAYBE;
+	private_data->message_id = NULL;
+	private_data->idp_list = NULL;
 
 	profile->server = NULL;
 	profile->request = NULL;
@@ -954,7 +985,7 @@ instance_init(LassoProfile *profile, G_GNUC_UNUSED void *unused)
 }
 
 static void
-class_init(LassoProfileClass *klass, void *unused G_GNUC_UNUSED)
+lasso_profile_class_init(LassoProfileClass *klass)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
@@ -963,33 +994,48 @@ class_init(LassoProfileClass *klass, void *unused G_GNUC_UNUSED)
 	lasso_node_class_set_nodename(nclass, "Profile");
 	lasso_node_class_set_ns(nclass, LASSO_LASSO_HREF, LASSO_LASSO_PREFIX);
 	lasso_node_class_add_snippets(nclass, schema_snippets);
-	g_type_class_add_private(klass, sizeof(LassoProfilePrivate));
 
 	G_OBJECT_CLASS(klass)->dispose = dispose;
 }
 
-GType
-lasso_profile_get_type()
+
+const char*
+lasso_profile_private_get_artifact(LassoProfile *profile)
 {
-	static GType this_type = 0;
-
-	if (!this_type) {
-		static const GTypeInfo this_info = {
-			sizeof(LassoProfileClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) class_init,
-			NULL,
-			NULL,
-			sizeof(LassoProfile),
-			0,
-			(GInstanceInitFunc) instance_init,
-			NULL
-		};
-
-		this_type = g_type_register_static(LASSO_TYPE_NODE,
-				"LassoProfile", &this_info, 0);
-	}
-	return this_type;
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+	return private_data->artifact;
 }
 
+void
+lasso_profile_set_artifact(LassoProfile *profile, char *artifact)
+{
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+	lasso_assign_string(private_data->artifact, artifact);
+}
+
+void
+lasso_profile_set_new_artifact(LassoProfile *profile, char *artifact)
+{
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+	lasso_assign_new_string(private_data->artifact, artifact);
+}
+
+void
+lasso_profile_set_new_artifact_message(LassoProfile *profile, char *artifact_message)
+{
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+	lasso_assign_string(private_data->artifact_message, artifact_message);
+}
+
+const char*
+lasso_profile_private_get_artifact_message(LassoProfile *profile)
+{
+	LassoProfilePrivate *private_data = lasso_profile_get_instance_private(profile);
+	return private_data->artifact_message;
+}
+
+gboolean
+lasso_profile_is_init(LassoProfile *profile)
+{
+	return lasso_profile_get_instance_private(profile) != NULL;
+}
