@@ -152,7 +152,7 @@ struct _LassoProfile {
 	LassoHttpMethod http_request_method;
 	gint signature_status;
 
-	LassoProfilePrivate *private_data;
+	LassoProfilePrivate *private_data __attribute__ ((deprecated));
 };
 
 struct _LassoProfileClass {
