@@ -44,9 +44,13 @@ struct _LassoProfilePrivate
 
 void lasso_profile_set_response_status(LassoProfile *profile, const gchar *statusCodeValue);
 void lasso_profile_clean_msg_info(LassoProfile *profile);
+const char *lasso_profile_private_get_artifact(LassoProfile *profile);
+void lasso_profile_set_artifact(LassoProfile *profile, char *artifact);
+void lasso_profile_set_new_artifact(LassoProfile *profile, char *artifact);
+void lasso_profile_set_new_artifact_message(LassoProfile *profile, char *artifact);
+const char *lasso_profile_private_get_artifact_message(LassoProfile *profile);
+gboolean lasso_profile_is_init(LassoProfile *profile);
 
-#define LASSO_PROFILE_GET_PRIVATE(o) \
-	   (G_TYPE_INSTANCE_GET_PRIVATE ((o), LASSO_TYPE_PROFILE, LassoProfilePrivate))
 
 #ifdef __cplusplus
 }
