@@ -67,6 +67,8 @@ use this default role to access descriptors.</para>
 #include "../debug.h"
 #include "../keyprivate.h"
 
+G_DEFINE_TYPE_WITH_PRIVATE(LassoProvider, lasso_provider, LASSO_TYPE_NODE);
+
 static char *protocol_uris[LASSO_MD_PROTOCOL_TYPE_LAST] = {
 	"http://projectliberty.org/profiles/fedterm",
 	"http://projectliberty.org/profiles/nim",
@@ -98,7 +100,8 @@ typedef int LassoProviderRoleIndex;
 
 static int
 lasso_provider_try_loading_public_keys(LassoProvider *provider, GList **public_keys, gboolean mandatory) {
-	if (provider->public_key || provider->private_data->signing_key_descriptors) {
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	if (provider->public_key || private_data->signing_key_descriptors) {
 		*public_keys = lasso_provider_get_public_keys(provider);
 		if (*public_keys == NULL)
 			return LASSO_DS_ERROR_PUBLIC_KEY_LOAD_FAILED;
@@ -144,10 +147,11 @@ lasso_provider_get_assertion_consumer_service_url(LassoProvider *provider, const
 {
 	char *name = NULL;
 	char *assertion_consumer_service_url = NULL;
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
 
 	g_return_val_if_fail(LASSO_IS_PROVIDER(provider), NULL);
 
-	if (provider->private_data->conformance == LASSO_PROTOCOL_SAML_2_0) {
+	if (private_data->conformance == LASSO_PROTOCOL_SAML_2_0) {
 		long sid = -1;
 		if (service_id != NULL) {
 			if (lasso_string_to_xsd_integer(service_id, &sid)) {
@@ -160,7 +164,7 @@ lasso_provider_get_assertion_consumer_service_url(LassoProvider *provider, const
 	}
 
 	if (service_id == NULL)
-		service_id = provider->private_data->default_assertion_consumer;
+		service_id = private_data->default_assertion_consumer;
 	name = g_strdup_printf("AssertionConsumerServiceURL %s", service_id);
 	assertion_consumer_service_url = lasso_provider_get_metadata_one_for_role(provider, LASSO_PROVIDER_ROLE_SP, name);
 	lasso_release(name);
@@ -197,9 +201,10 @@ _lasso_provider_add_metadata_value_for_role(LassoProvider *provider, LassoProvid
 	GHashTable *descriptor;
 	char *symbol;
 	const char *role_prefix;
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
 
 	g_return_if_fail(LASSO_IS_PROVIDER(provider) && name && value);
-	descriptor = provider->private_data->Descriptors; /* default to SP */
+	descriptor = private_data->Descriptors; /* default to SP */
 	g_return_if_fail (descriptor);
 	l = (GList*)lasso_provider_get_metadata_list_for_role(provider, role, name);
 	lasso_list_add_string(l, value);
@@ -230,11 +235,12 @@ lasso_provider_get_metadata_list_for_role(const LassoProvider *provider, LassoPr
 	GHashTable *descriptor;
 	char *symbol;
 	const char *role_prefix;
+	const LassoProviderPrivate *private_data = lasso_provider_get_instance_private((LassoProvider*)provider);
 
 	g_return_val_if_fail(LASSO_IS_PROVIDER(provider) && name, NULL);
 	g_return_val_if_fail(_lasso_provider_get_role_index(role), NULL);
 
-	descriptor = provider->private_data->Descriptors; /* default to SP */
+	descriptor = private_data->Descriptors; /* default to SP */
 	if (descriptor == NULL)
 		return NULL;
 
@@ -324,10 +330,11 @@ lasso_provider_get_first_http_method(LassoProvider *provider,
 	const GList *t1, *t2 = NULL;
 	gboolean found;
 	const gchar *role_prefix;
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
 
 	g_return_val_if_fail(LASSO_IS_PROVIDER(provider), LASSO_HTTP_METHOD_NONE);
 	g_return_val_if_fail(remote_provider != NULL, LASSO_HTTP_METHOD_NONE);
-	if (provider->private_data->conformance == LASSO_PROTOCOL_SAML_2_0) {
+	if (private_data->conformance == LASSO_PROTOCOL_SAML_2_0) {
 		return lasso_saml20_provider_get_first_http_method(
 				provider, remote_provider, protocol_type);
 	}
@@ -396,9 +403,10 @@ lasso_provider_accept_http_method(LassoProvider *provider, LassoProvider *remote
 	LassoProviderRole initiating_role;
 	char *protocol_profile;
 	const gchar *role_prefix;
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
 
 	g_return_val_if_fail(LASSO_IS_PROVIDER(provider), FALSE); /* Be conservative */
-	if (provider->private_data->conformance == LASSO_PROTOCOL_SAML_2_0) {
+	if (private_data->conformance == LASSO_PROTOCOL_SAML_2_0) {
 		return lasso_saml20_provider_accept_http_method(
 				provider, remote_provider, protocol_type,
 				http_method, initiate_profile);
@@ -499,8 +507,9 @@ xmlNode*
 lasso_provider_get_organization(const LassoProvider *provider)
 {
 	g_return_val_if_fail(LASSO_IS_PROVIDER(provider), NULL);
-	if (provider->private_data->organization) {
-		return xmlCopyNode(provider->private_data->organization, 1);
+	const LassoProviderPrivate *private_data = lasso_provider_get_instance_private((LassoProvider*)provider);
+	if (private_data->organization) {
+		return xmlCopyNode(private_data->organization, 1);
 	} else {
 		return NULL;
 	}
@@ -536,7 +545,8 @@ GList*
 lasso_provider_get_public_keys(const LassoProvider *provider)
 {
 	g_return_val_if_fail(LASSO_IS_PROVIDER(provider), NULL);
-	return provider->private_data->signing_public_keys;
+	const LassoProviderPrivate *private_data = lasso_provider_get_instance_private((LassoProvider*)provider);
+	return private_data->signing_public_keys;
 }
 
 /**
@@ -553,8 +563,9 @@ lasso_provider_get_encryption_public_key(const LassoProvider *provider)
 {
 	g_return_val_if_fail(LASSO_IS_PROVIDER(provider), NULL);
 	GList *keys;
+	const LassoProviderPrivate *private_data = lasso_provider_get_instance_private((LassoProvider*)provider);
 
-	keys = provider->private_data->encryption_public_keys;
+	keys = private_data->encryption_public_keys;
 	/* encrypt using the first given key, multiple encryption key in the metadata is generally
 	 * useless. roll-over of the encryption key is done mainly at the receiving side, by trying
 	 * to decipher using the two private keys, the old and the new. */
@@ -570,6 +581,7 @@ _lasso_provider_load_endpoint_type(LassoProvider *provider, xmlNode *endpoint,
 {
 	char *name = (char*)endpoint->name;
 	xmlChar *value = NULL;
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
 
 	if (strcmp(name, "AssertionConsumerServiceURL") == 0) {
 		char *isDefault = (char*)xmlGetProp(endpoint, (xmlChar*)"isDefault");
@@ -577,7 +589,7 @@ _lasso_provider_load_endpoint_type(LassoProvider *provider, xmlNode *endpoint,
 		name = g_strdup_printf("%s %s", name, id);
 		if (isDefault) {
 			if (strcmp(isDefault, "true") == 0 || strcmp(isDefault, "1") == 0)
-				lasso_assign_string(provider->private_data->default_assertion_consumer,
+				lasso_assign_string(private_data->default_assertion_consumer,
 					id);
 			xmlFree(isDefault);
 		}
@@ -628,6 +640,7 @@ get_xmlNode(LassoNode *node, gboolean lasso_dump)
 		"Assertion",
 		"Both"
 	};
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
 
 	xmlnode = parent_class->get_xmlNode(node, lasso_dump);
 
@@ -639,7 +652,7 @@ get_xmlNode(LassoNode *node, gboolean lasso_dump)
 
 	/* Save encryption mode */
 	xmlSetProp(xmlnode, (xmlChar*)"EncryptionMode",
-		(xmlChar*)encryption_mode[provider->private_data->encryption_mode]);
+		(xmlChar*)encryption_mode[private_data->encryption_mode]);
 
 	return xmlnode;
 }
@@ -651,9 +664,9 @@ _lasso_provider_load_key_descriptor(LassoProvider *provider, xmlNode *key_descri
 	xmlChar *use;
 
 	g_return_if_fail(LASSO_IS_PROVIDER(provider));
-	g_return_if_fail(provider->private_data);
+	private_data = lasso_provider_get_instance_private(provider);
+	g_return_if_fail(private_data);
 
-	private_data = provider->private_data;
 	use = xmlGetProp(key_descriptor, (xmlChar*)"use");
 	if (use == NULL || lasso_strisequal((char *)use,"signing")) {
 		lasso_list_add_xml_node(private_data->signing_key_descriptors,
@@ -681,6 +694,7 @@ init_from_xml(LassoNode *node, xmlNode *xmlnode)
 	xmlChar *s;
 	int i;
 	int rc = 0;
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
 
 	parent_class->init_from_xml(node, xmlnode);
 
@@ -706,11 +720,11 @@ init_from_xml(LassoNode *node, xmlNode *xmlnode)
 	/* Load encryption mode */
 	s = xmlGetProp(xmlnode, (xmlChar*)"EncryptionMode");
 	if (s != NULL && strcmp((char*)s, "NameId") == 0) {
-		provider->private_data->encryption_mode = LASSO_ENCRYPTION_MODE_NAMEID;
+		private_data->encryption_mode = LASSO_ENCRYPTION_MODE_NAMEID;
 	} else if (s != NULL && strcmp((char*)s, "Assertion") == 0) {
-		provider->private_data->encryption_mode = LASSO_ENCRYPTION_MODE_ASSERTION;
+		private_data->encryption_mode = LASSO_ENCRYPTION_MODE_ASSERTION;
 	} else if (s != NULL && strcmp((char*)s, "Both") == 0) {
-		provider->private_data->encryption_mode =
+		private_data->encryption_mode =
 			LASSO_ENCRYPTION_MODE_NAMEID | LASSO_ENCRYPTION_MODE_ASSERTION;
 	}
 	if (s != NULL) {
@@ -745,10 +759,8 @@ init_from_xml(LassoNode *node, xmlNode *xmlnode)
 static void*
 _lasso_provider_get_pdata_thing(LassoProvider *provider, ptrdiff_t offset)
 {
-	LassoProviderPrivate *pdata;
-
 	lasso_return_val_if_fail(LASSO_IS_PROVIDER(provider), NULL);
-	pdata = provider->private_data;
+	LassoProviderPrivate *pdata = lasso_provider_get_instance_private(provider);
 	if (pdata)
 		return G_STRUCT_MEMBER_P(pdata, offset);
 
@@ -827,51 +839,52 @@ static void
 dispose(GObject *object)
 {
 	LassoProvider *provider = LASSO_PROVIDER(object);
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
 
-	if (provider->private_data->dispose_has_run) {
+	if (private_data->dispose_has_run) {
 		return;
 	}
-	provider->private_data->dispose_has_run = TRUE;
+	private_data->dispose_has_run = TRUE;
 
-	lasso_release_ghashtable(provider->private_data->Descriptors);
+	lasso_release_ghashtable(private_data->Descriptors);
 
-	if (provider->private_data->organization) {
-		xmlFreeNode(provider->private_data->organization);
-		provider->private_data->organization = NULL;
+	if (private_data->organization) {
+		xmlFreeNode(private_data->organization);
+		private_data->organization = NULL;
 	}
 
-	if (provider->private_data->default_assertion_consumer) {
-		lasso_release(provider->private_data->default_assertion_consumer);
-		provider->private_data->default_assertion_consumer = NULL;
+	if (private_data->default_assertion_consumer) {
+		lasso_release(private_data->default_assertion_consumer);
+		private_data->default_assertion_consumer = NULL;
 	}
 
-	if (provider->private_data->signing_public_keys) {
-		lasso_release_list_of_sec_key(provider->private_data->signing_public_keys);
+	if (private_data->signing_public_keys) {
+		lasso_release_list_of_sec_key(private_data->signing_public_keys);
 	}
 
-	if (provider->private_data->signing_key_descriptors) {
-		lasso_release_list_of_xml_node(provider->private_data->signing_key_descriptors);
+	if (private_data->signing_key_descriptors) {
+		lasso_release_list_of_xml_node(private_data->signing_key_descriptors);
 	}
 
-	if (provider->private_data->encryption_key_descriptor) {
-		xmlFreeNode(provider->private_data->encryption_key_descriptor);
-		provider->private_data->encryption_key_descriptor = NULL;
+	if (private_data->encryption_key_descriptor) {
+		xmlFreeNode(private_data->encryption_key_descriptor);
+		private_data->encryption_key_descriptor = NULL;
 	}
 
-	if (provider->private_data->encryption_public_key_str) {
-		lasso_release(provider->private_data->encryption_public_key_str);
-		provider->private_data->encryption_public_key_str = NULL;
+	if (private_data->encryption_public_key_str) {
+		lasso_release(private_data->encryption_public_key_str);
+		private_data->encryption_public_key_str = NULL;
 	}
 
-	lasso_release_list_of_sec_key(provider->private_data->encryption_public_keys);
+	lasso_release_list_of_sec_key(private_data->encryption_public_keys);
 
-	lasso_release(provider->private_data->affiliation_id);
-	provider->private_data->affiliation_id = NULL;
-	lasso_release(provider->private_data->affiliation_owner_id);
-	provider->private_data->affiliation_owner_id = NULL;
-	lasso_release_list_of_full(provider->private_data->endpoints, lasso_endpoint_free);
+	lasso_release(private_data->affiliation_id);
+	private_data->affiliation_id = NULL;
+	lasso_release(private_data->affiliation_owner_id);
+	private_data->affiliation_owner_id = NULL;
+	lasso_release_list_of_full(private_data->endpoints, lasso_endpoint_free);
 
-	lasso_assign_new_signature_context(provider->private_data->signature_context,
+	lasso_assign_new_signature_context(private_data->signature_context,
 			LASSO_SIGNATURE_CONTEXT_NONE);
 
 	G_OBJECT_CLASS(parent_class)->dispose(G_OBJECT(provider));
@@ -882,38 +895,43 @@ dispose(GObject *object)
 /*****************************************************************************/
 
 static void
-instance_init(LassoProvider *provider, G_GNUC_UNUSED void *unused)
+lasso_provider_init(LassoProvider *provider)
 {
 	provider->role = LASSO_PROVIDER_ROLE_NONE;
 	provider->ProviderID = NULL;
 	provider->metadata_filename = NULL;
 	provider->public_key = NULL;
 	provider->ca_cert_chain = NULL;
-	provider->private_data = G_TYPE_INSTANCE_GET_PRIVATE(provider, LASSO_TYPE_PROVIDER,
-			LassoProviderPrivate);
-	provider->private_data->dispose_has_run = FALSE;
-	provider->private_data->default_assertion_consumer = NULL;
-	provider->private_data->affiliation_id = NULL;
-	provider->private_data->affiliation_owner_id = NULL;
-	provider->private_data->organization = NULL;
-	provider->private_data->signing_public_keys = NULL;
-	provider->private_data->signing_key_descriptors = NULL;
-	provider->private_data->encryption_key_descriptor = NULL;
-	provider->private_data->encryption_public_key_str = NULL;
-	provider->private_data->encryption_public_keys = NULL;
-	provider->private_data->encryption_mode = LASSO_ENCRYPTION_MODE_NONE;
-	provider->private_data->encryption_sym_key_type = LASSO_ENCRYPTION_SYM_KEY_TYPE_AES_128;
-	provider->private_data->key_encryption_method = LASSO_KEY_ENCRYPTION_METHOD_DEFAULT;
-	provider->private_data->signature_context = LASSO_SIGNATURE_CONTEXT_NONE;
+
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	private_data->dispose_has_run = FALSE;
+	private_data->default_assertion_consumer = NULL;
+	private_data->affiliation_id = NULL;
+	private_data->affiliation_owner_id = NULL;
+	private_data->organization = NULL;
+	private_data->signing_public_keys = NULL;
+	private_data->signing_key_descriptors = NULL;
+	private_data->encryption_key_descriptor = NULL;
+	private_data->encryption_public_key_str = NULL;
+	private_data->encryption_public_keys = NULL;
+	private_data->encryption_mode = LASSO_ENCRYPTION_MODE_NONE;
+	private_data->encryption_sym_key_type = LASSO_ENCRYPTION_SYM_KEY_TYPE_AES_128;
+	private_data->key_encryption_method = LASSO_KEY_ENCRYPTION_METHOD_DEFAULT;
+	private_data->signature_context = LASSO_SIGNATURE_CONTEXT_NONE;
 
 	/* no value_destroy_func since it shouldn't destroy the GList on insert */
-	provider->private_data->Descriptors = g_hash_table_new_full(
-			g_str_hash, g_str_equal, g_free, (GFreeFunc)free_list_strings);
-	provider->private_data->attributes = NULL;
+	private_data->Descriptors = g_hash_table_new_full(
+	      g_str_hash, g_str_equal, g_free, (GFreeFunc)free_list_strings);
+	private_data->attributes = NULL;
+
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+	provider->private_data = private_data;
+#pragma GCC diagnostic pop
 }
 
 static void
-class_init(LassoProviderClass *klass, void *unused G_GNUC_UNUSED)
+lasso_provider_class_init(LassoProviderClass *klass)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
@@ -926,33 +944,8 @@ class_init(LassoProviderClass *klass, void *unused G_GNUC_UNUSED)
 	nclass->init_from_xml = init_from_xml;
 
 	G_OBJECT_CLASS(klass)->dispose = dispose;
-	g_type_class_add_private(G_OBJECT_CLASS(klass), sizeof(LassoProviderPrivate));
 }
 
-GType
-lasso_provider_get_type()
-{
-	static GType this_type = 0;
-
-	if (!this_type) {
-		static const GTypeInfo this_info = {
-			sizeof (LassoProviderClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) class_init,
-			NULL,
-			NULL,
-			sizeof(LassoProvider),
-			0,
-			(GInstanceInitFunc) instance_init,
-			NULL
-		};
-
-		this_type = g_type_register_static(LASSO_TYPE_NODE,
-				"LassoProvider", &this_info, 0);
-	}
-	return this_type;
-}
 
 /**
  * lasso_provider_get_protocol_conformance:
@@ -967,7 +960,8 @@ LassoProtocolConformance
 lasso_provider_get_protocol_conformance(const LassoProvider *provider)
 {
 	g_return_val_if_fail(LASSO_IS_PROVIDER(provider), LASSO_PROTOCOL_NONE);
-	return provider->private_data->conformance;
+	const LassoProviderPrivate *private_data = lasso_provider_get_instance_private((LassoProvider*)provider);
+	return private_data->conformance;
 }
 
 /**
@@ -993,7 +987,8 @@ lasso_provider_get_protocol_conformance(const LassoProvider *provider)
 void
 lasso_provider_set_protocol_conformance(LassoProvider *provider, LassoProtocolConformance protocol_conformance)
 {
-	provider->private_data->conformance = protocol_conformance;
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	private_data->conformance = protocol_conformance;
 }
 
 gboolean
@@ -1068,6 +1063,7 @@ _lasso_provider_load_metadata_from_xmlnode(LassoProvider *provider, xmlNode *nod
 	const char *xpath_sp = "/md:EntityDescriptor/md:SPDescriptor";
 	const char *xpath_organization = "/md:EntityDescriptor/md:Organization";
 	xmlChar *providerID = NULL;
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
 
 	g_return_val_if_fail(LASSO_IS_PROVIDER(provider), FALSE);
 	g_return_val_if_fail(node != NULL && node->ns != NULL, FALSE);
@@ -1079,12 +1075,12 @@ _lasso_provider_load_metadata_from_xmlnode(LassoProvider *provider, xmlNode *nod
 
 	if (strcmp((char*)node->ns->href, LASSO_SAML2_METADATA_HREF) == 0) {
 		gboolean result;
-		provider->private_data->conformance = LASSO_PROTOCOL_SAML_2_0;
+		private_data->conformance = LASSO_PROTOCOL_SAML_2_0;
 		result = lasso_saml20_provider_load_metadata(provider, node);
 		return result;
 	}
 
-	provider->private_data->conformance = LASSO_PROTOCOL_LIBERTY_1_2;
+	private_data->conformance = LASSO_PROTOCOL_LIBERTY_1_2;
 
 	xpathCtx = xmlXPathNewContext(doc);
 	xmlXPathRegisterNs(xpathCtx, (xmlChar*)"md", (xmlChar*)LASSO_METADATA_HREF);
@@ -1102,7 +1098,7 @@ _lasso_provider_load_metadata_from_xmlnode(LassoProvider *provider, xmlNode *nod
 			xmlXPathFreeContext(xpathCtx);
 			return FALSE;
 		}
-		provider->private_data->conformance = LASSO_PROTOCOL_LIBERTY_1_1;
+		private_data->conformance = LASSO_PROTOCOL_LIBERTY_1_1;
 		xpath_idp = "/md11:IDPDescriptor";
 		xpath_sp = "/md11:SPDescriptor";
 	}
@@ -1116,7 +1112,7 @@ _lasso_provider_load_metadata_from_xmlnode(LassoProvider *provider, xmlNode *nod
 	if (xpathObj && xpathObj->nodesetval && xpathObj->nodesetval->nodeNr == 1) {
 		_lasso_provider_load_descriptor(provider, xpathObj->nodesetval->nodeTab[0],
 				LASSO_PROVIDER_ROLE_IDP);
-		if (provider->private_data->conformance < LASSO_PROTOCOL_LIBERTY_1_2) {
+		if (private_data->conformance < LASSO_PROTOCOL_LIBERTY_1_2) {
 			/* lookup ProviderID */
 			node = xpathObj->nodesetval->nodeTab[0]->children;
 			while (node) {
@@ -1136,7 +1132,7 @@ _lasso_provider_load_metadata_from_xmlnode(LassoProvider *provider, xmlNode *nod
 	if (xpathObj && xpathObj->nodesetval && xpathObj->nodesetval->nodeNr == 1) {
 		_lasso_provider_load_descriptor(provider, xpathObj->nodesetval->nodeTab[0],
 				LASSO_PROVIDER_ROLE_SP);
-		if (provider->private_data->conformance < LASSO_PROTOCOL_LIBERTY_1_2) {
+		if (private_data->conformance < LASSO_PROTOCOL_LIBERTY_1_2) {
 			/* lookup ProviderID */
 			node = xpathObj->nodesetval->nodeTab[0]->children;
 			while (node) {
@@ -1154,7 +1150,7 @@ _lasso_provider_load_metadata_from_xmlnode(LassoProvider *provider, xmlNode *nod
 
 	xpathObj = xmlXPathEvalExpression((xmlChar*)xpath_organization, xpathCtx);
 	if (xpathObj && xpathObj->nodesetval && xpathObj->nodesetval->nodeNr == 1) {
-		lasso_assign_xml_node(provider->private_data->organization,
+		lasso_assign_xml_node(private_data->organization,
 				xpathObj->nodesetval->nodeTab[0]);
 	}
 	xmlXPathFreeObject(xpathObj);
@@ -1175,7 +1171,8 @@ _lasso_provider_new_helper(LassoProviderRole role, const char *metadata,
 		const char *public_key, const char *ca_cert_chain, gboolean (*loader)(
 			LassoProvider *provider, const gchar *metadata))
 {
-	LassoProvider *provider = NULL, *ret = NULL;
+	LassoProvider *provider, *ret = NULL;
+	LassoProviderPrivate *private_data;
 
 	provider = (LassoProvider*)g_object_new(LASSO_TYPE_PROVIDER, NULL);
 	provider->role = role;
@@ -1199,7 +1196,8 @@ _lasso_provider_new_helper(LassoProviderRole role, const char *metadata,
 		goto cleanup;
 	}
 
-	provider->private_data->encryption_mode = LASSO_ENCRYPTION_MODE_NONE;
+	private_data = lasso_provider_get_instance_private(provider);
+	private_data->encryption_mode = LASSO_ENCRYPTION_MODE_NONE;
 	lasso_transfer_gobject(ret, provider);
 cleanup:
 	lasso_release_gobject(provider);
@@ -1262,11 +1260,13 @@ lasso_provider_load_public_key(LassoProvider *provider, LassoPublicKeyType publi
 	gboolean ret = FALSE;
 
 	g_return_val_if_fail(LASSO_IS_PROVIDER(provider), FALSE);
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+
 	if (public_key_type == LASSO_PUBLIC_KEY_SIGNING) {
 		public_key = provider->public_key;
-		keys_descriptors = provider->private_data->signing_key_descriptors;
+		keys_descriptors = private_data->signing_key_descriptors;
 	} else {
-		key_descriptor = provider->private_data->encryption_key_descriptor;
+		key_descriptor = private_data->encryption_key_descriptor;
 	}
 
 	if (public_key == NULL && keys_descriptors == NULL && key_descriptor == NULL) {
@@ -1311,10 +1311,10 @@ lasso_provider_load_public_key(LassoProvider *provider, LassoPublicKeyType publi
 		GList **dest = NULL;
 		switch (public_key_type) {
 			case LASSO_PUBLIC_KEY_SIGNING:
-				dest = &provider->private_data->signing_public_keys;
+				dest = &private_data->signing_public_keys;
 				break;
 			case LASSO_PUBLIC_KEY_ENCRYPTION:
-				dest = &provider->private_data->encryption_public_keys;
+				dest = &private_data->encryption_public_keys;
 				break;
 		}
 		if (dest) {
@@ -1364,8 +1364,8 @@ lasso_provider_verify_saml_signature(LassoProvider *provider,
 
 	/* ID-FF 1.2 Signatures case */
 	node_ns = xmlSecGetNodeNsHref(signed_node);
-	if ((strcmp((char*)node_ns, LASSO_SAML2_PROTOCOL_HREF) == 0) ||
-			(strcmp((char*)node_ns, LASSO_SAML2_ASSERTION_HREF) == 0)) {
+	if (node_ns && ((strcmp((char*)node_ns, LASSO_SAML2_PROTOCOL_HREF) == 0) ||
+			(strcmp((char*)node_ns, LASSO_SAML2_ASSERTION_HREF) == 0))) {
 		id_attribute_name = "ID";
 	} else if (xmlSecCheckNodeName(signed_node, (xmlChar*)"Request", (xmlChar*)LASSO_SAML_PROTOCOL_HREF)) {
 		id_attribute_name = "RequestID";
@@ -1486,7 +1486,8 @@ void
 lasso_provider_set_encryption_mode(LassoProvider *provider, LassoEncryptionMode encryption_mode)
 {
 	g_return_if_fail(LASSO_IS_PROVIDER(provider));
-	provider->private_data->encryption_mode = encryption_mode;
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	private_data->encryption_mode = encryption_mode;
 }
 
 /**
@@ -1499,9 +1500,14 @@ lasso_provider_set_encryption_mode(LassoProvider *provider, LassoEncryptionMode
  */
 LassoEncryptionMode
 lasso_provider_get_encryption_mode(LassoProvider *provider) {
-	if (! LASSO_IS_PROVIDER(provider) || ! provider->private_data)
+	if (! LASSO_IS_PROVIDER(provider)) {
 		return LASSO_ENCRYPTION_MODE_NONE;
-	return provider->private_data->encryption_mode;
+	}
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	if (! private_data) {
+		return LASSO_ENCRYPTION_MODE_NONE;
+	}
+	return private_data->encryption_mode;
 }
 
 /**
@@ -1516,7 +1522,8 @@ lasso_provider_set_encryption_sym_key_type(LassoProvider *provider,
 		LassoEncryptionSymKeyType encryption_sym_key_type)
 {
 	g_return_if_fail(LASSO_IS_PROVIDER(provider));
-	provider->private_data->encryption_sym_key_type = encryption_sym_key_type;
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	private_data->encryption_sym_key_type = encryption_sym_key_type;
 }
 
 /**
@@ -1530,8 +1537,14 @@ lasso_provider_set_encryption_sym_key_type(LassoProvider *provider,
 LassoEncryptionSymKeyType
 lasso_provider_get_encryption_sym_key_type(const LassoProvider *provider)
 {
-	if (LASSO_IS_PROVIDER(provider) && provider->private_data)
-		return provider->private_data->encryption_sym_key_type;
+	if (LASSO_IS_PROVIDER(provider))
+	{
+		const LassoProviderPrivate *private_data = lasso_provider_get_instance_private((LassoProvider*)provider);
+		if (private_data)
+		{
+			return private_data->encryption_sym_key_type;
+		}
+	}
 
 	return LASSO_ENCRYPTION_SYM_KEY_TYPE_DEFAULT;
 }
@@ -1548,11 +1561,12 @@ lasso_provider_set_key_encryption_method(LassoProvider *provider,
 		LassoKeyEncryptionMethod key_encryption_method)
 {
 	g_return_if_fail(LASSO_IS_PROVIDER(provider));
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
 
 	if (key_encryption_method == LASSO_KEY_ENCRYPTION_METHOD_DEFAULT) {
 		key_encryption_method = lasso_get_default_key_encryption_method();
 	}
-	provider->private_data->key_encryption_method = key_encryption_method;;
+	private_data->key_encryption_method = key_encryption_method;;
 }
 
 /**
@@ -1566,9 +1580,14 @@ lasso_provider_set_key_encryption_method(LassoProvider *provider,
 LassoKeyEncryptionMethod
 lasso_provider_get_key_encryption_method(const LassoProvider *provider)
 {
-	if (LASSO_IS_PROVIDER(provider) && provider->private_data)
-		if (provider->private_data->key_encryption_method != LASSO_KEY_ENCRYPTION_METHOD_DEFAULT)
-			return provider->private_data->key_encryption_method;
+	if (LASSO_IS_PROVIDER(provider))
+	{
+		const LassoProviderPrivate *private_data = lasso_provider_get_instance_private((LassoProvider*)provider);
+		if (private_data && private_data->key_encryption_method != LASSO_KEY_ENCRYPTION_METHOD_DEFAULT)
+		{
+			return private_data->key_encryption_method;
+		}
+	}
 
 	return lasso_get_default_key_encryption_method();
 }
@@ -1657,11 +1676,12 @@ lasso_provider_get_sp_name_qualifier(LassoProvider *provider)
 	const char *sp_name_qualifier;
 
 	g_return_val_if_fail(LASSO_IS_PROVIDER(provider), NULL);
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
 	/* should not happen ! */
-	g_return_val_if_fail(provider->private_data != NULL, NULL);
+	g_return_val_if_fail(private_data != NULL, NULL);
 
-	if (provider->private_data->affiliation_id) {
-		sp_name_qualifier = provider->private_data->affiliation_id;
+	if (private_data->affiliation_id) {
+		sp_name_qualifier = private_data->affiliation_id;
 	} else {
 		sp_name_qualifier = provider->ProviderID;
 	}
@@ -1746,11 +1766,12 @@ lasso_provider_get_metadata_keys_for_role(LassoProvider *provider, LassoProvider
 	struct AddForRoleHelper helper = { NULL, role };
 
 	lasso_return_val_if_fail(LASSO_IS_PROVIDER(provider), NULL);
-	lasso_return_val_if_fail(provider->private_data != NULL, NULL);
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	lasso_return_val_if_fail(private_data != NULL, NULL);
 	lasso_return_val_if_fail(role > LASSO_PROVIDER_ROLE_NONE && role < LASSO_PROVIDER_ROLE_LAST, NULL);
 	g_return_val_if_fail(role_to_prefix(role) != NULL, NULL);
 
-	g_hash_table_foreach(provider->private_data->Descriptors, (GHFunc)_add_for_role, &helper);
+	g_hash_table_foreach(private_data->Descriptors, (GHFunc)_add_for_role, &helper);
 
 	return helper.l;
 }
@@ -1766,9 +1787,12 @@ lasso_provider_get_metadata_keys_for_role(LassoProvider *provider, LassoProvider
 LassoProviderRole
 lasso_provider_get_roles(LassoProvider *provider)
 {
-	lasso_return_val_if_fail(LASSO_IS_PROVIDER(provider) && provider->private_data, LASSO_PROVIDER_ROLE_NONE);
-
-	return provider->private_data->roles;
+	lasso_return_val_if_fail(
+			LASSO_IS_PROVIDER(provider)\
+				&& lasso_provider_get_instance_private(provider),
+			LASSO_PROVIDER_ROLE_NONE);
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	return private_data->roles;
 }
 
 /**
@@ -1813,7 +1837,8 @@ lasso_provider_new_from_xmlnode(LassoProviderRole role, xmlNode *node) {
 		goto cleanup;
 	}
 
-	provider->private_data->encryption_mode = LASSO_ENCRYPTION_MODE_NONE;
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	private_data->encryption_mode = LASSO_ENCRYPTION_MODE_NONE;
 	lasso_transfer_gobject(ret, provider);
 cleanup:
 	lasso_release_gobject(provider);
@@ -1839,14 +1864,16 @@ lasso_provider_add_key(LassoProvider *provider, LassoKey *key, gboolean after)
 	lasso_error_t rc = 0;
 	GList **list = NULL;
 	xmlSecKey *xml_sec_key = NULL;
+	LassoProviderPrivate *private_data = NULL;
 
 	lasso_bad_param(PROVIDER, provider);
 	lasso_bad_param(KEY, key);
 
 	switch (lasso_key_get_key_type(key)) {
 		case LASSO_KEY_TYPE_FOR_SIGNATURE:
+			private_data = lasso_provider_get_instance_private(provider);
 			context = lasso_key_get_signature_context(key);
-			list = &provider->private_data->signing_public_keys;
+			list = &private_data->signing_public_keys;
 			xml_sec_key = xmlSecKeyDuplicate(context.signature_key);
 			break;
 	}
@@ -1880,8 +1907,128 @@ lasso_provider_set_server_signing_key(LassoProvider *provider,
 	context = lasso_key_get_signature_context(key);
 	goto_cleanup_if_fail_with_rc(lasso_validate_signature_context(context),
 			LASSO_DS_ERROR_PRIVATE_KEY_LOAD_FAILED);
-	lasso_assign_signature_context(provider->private_data->signature_context,
+
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	lasso_assign_signature_context(private_data->signature_context,
 			context);
 cleanup:
 	return rc;
 }
+
+/*****************************************************************************/
+/* Non exported methods, headers in providerprivate.h */
+/* used by id-ff/server.c saml-2.0/server.c saml-2.0/provider.c*/
+/*****************************************************************************/
+
+gboolean
+lasso_provider_is_init(LassoProvider *provider)
+{
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	return private_data != NULL;
+}
+
+const LassoSignatureContext*
+lasso_provider_get_signature_context(LassoProvider *provider)
+{
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private((LassoProvider*)provider);
+	return &private_data->signature_context;
+}
+
+const char*
+lasso_provider_get_affiliation_owner_id(LassoProvider *provider)
+{
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	return private_data->affiliation_owner_id;
+}
+
+void
+lasso_provider_release_affiliation_owner_id(LassoProvider *provider)
+{
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	lasso_release_string(private_data->affiliation_owner_id);
+}
+
+void
+lasso_provider_set_affiliation_owner_id(LassoProvider *provider, const char *affiliation_owner_id)
+{
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	private_data->affiliation_owner_id = g_strdup(affiliation_owner_id);
+}
+
+void
+lasso_provider_set_affiliation_id(LassoProvider *provider, const char *affiliation_id)
+{
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	private_data->affiliation_id = g_strdup(affiliation_id);
+}
+
+void
+lasso_provider_set_valid_until_from_prop(LassoProvider *provider, xmlNode *node, xmlChar *name, xmlChar *ns)
+{
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	lasso_set_string_from_prop(&private_data->valid_until, node, name, ns);
+}
+
+void lasso_provider_set_cache_duration_from_prop(LassoProvider *provider, xmlNode *node, xmlChar *name, xmlChar *ns)
+{
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	lasso_set_string_from_prop(&private_data->cache_duration, node, name, ns);
+}
+
+
+const char*
+lasso_provider_get_default_assertion_consumer(LassoProvider *provider)
+{
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	return private_data->default_assertion_consumer;
+}
+
+void
+lasso_provider_set_default_assertion_consumer(LassoProvider *provider, char *assertion_consumer)
+{
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	lasso_assign_string(private_data->default_assertion_consumer,
+			assertion_consumer);
+}
+
+void
+lasso_provider_sort_endpoints(LassoProvider *provider, GCompareFunc cmpfun)
+{
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	private_data->endpoints = g_list_sort(private_data->endpoints, cmpfun);
+}
+
+void
+lasso_provider_add_endpoint(LassoProvider *provider, EndpointType *endpoint)
+{
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	lasso_list_add(private_data->endpoints, (void*)endpoint);
+}
+
+const GList*
+lasso_provider_get_endpoints(LassoProvider *provider)
+{
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	return private_data->endpoints;
+}
+
+void
+lasso_provider_add_attribute(LassoProvider *provider, LassoSaml2Attribute *attribute)
+{
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	lasso_list_add(private_data->attributes, (void*)attribute);
+}
+
+void
+lasso_provider_set_organization(LassoProvider *provider, xmlNode *organization)
+{
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	lasso_assign_xml_node(private_data->organization, organization);
+}
+
+void
+lasso_provider_set_roles(LassoProvider *provider, LassoProviderRole roles)
+{
+	LassoProviderPrivate *private_data = lasso_provider_get_instance_private(provider);
+	private_data->roles = roles;
+}
