@@ -26,6 +26,7 @@
 
 #include <./serverprivate.h>
 #include "../xml/private.h"
+#include "../xml/saml-2.0/saml2_attribute.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -45,7 +46,7 @@ typedef enum {
 } LassoPublicKeyType;
 
 /* This structure should allow to map ID-FFv1.2 and SAMLv2 endpoints */
-struct EndpointType_s {
+typedef struct _EndpointType {
 	LassoProviderRole role;
 	char *kind;
 	char *binding;
@@ -53,8 +54,7 @@ struct EndpointType_s {
 	char *return_url;
 	int index;
 	int is_default;
-};
-typedef struct EndpointType_s EndpointType;
+} EndpointType;
 
 
 struct _LassoProviderPrivate
@@ -93,12 +93,27 @@ GList* lasso_provider_get_public_keys(const LassoProvider *provider);
 xmlSecKey* lasso_provider_get_encryption_public_key(const LassoProvider *provider);
 LassoEncryptionSymKeyType lasso_provider_get_encryption_sym_key_type(const LassoProvider* provider);
 LassoKeyEncryptionMethod lasso_provider_get_key_encryption_method(const LassoProvider* provider);
-int lasso_provider_verify_saml_signature(LassoProvider *provider, xmlNode *signed_node, xmlDoc *doc);
 int lasso_provider_verify_query_signature(LassoProvider *provider, const char *message);
 void _lasso_provider_load_key_descriptor(LassoProvider *provider, xmlNode *key_descriptor);
 void _lasso_provider_add_metadata_value_for_role(LassoProvider *provider,
 		LassoProviderRole role, const char *name, const char *value);
 LassoProvider* lasso_provider_new_from_xmlnode(LassoProviderRole role, xmlNode *node);
+gboolean lasso_provider_is_init(LassoProvider *provider);
+const LassoSignatureContext *lasso_provider_get_signature_context(LassoProvider *provider);
+const char *lasso_provider_get_affiliation_owner_id(LassoProvider *provider);
+void lasso_provider_release_affiliation_owner_id(LassoProvider *provider);
+void lasso_provider_set_affiliation_owner_id(LassoProvider *provider, const char *affiliation_owner_id);
+void lasso_provider_set_affiliation_id(LassoProvider *provider, const char *affiliation_id);
+void lasso_provider_set_valid_until_from_prop(LassoProvider *provider, xmlNode *node, xmlChar *name, xmlChar *ns);
+void lasso_provider_set_cache_duration_from_prop(LassoProvider *provider, xmlNode *node, xmlChar *name, xmlChar *ns);
+const char *lasso_provider_get_default_assertion_consumer(LassoProvider *provider);
+void lasso_provider_set_default_assertion_consumer(LassoProvider *provider, char *assertion_consumer);
+void lasso_provider_sort_endpoints(LassoProvider *provider, GCompareFunc cmpfun);
+void lasso_provider_add_endpoint(LassoProvider *provider, EndpointType *endpoint);
+const GList *lasso_provider_get_endpoints(LassoProvider *provider);
+void lasso_provider_add_attribute(LassoProvider *provider, LassoSaml2Attribute *attribute);
+void lasso_provider_set_organization(LassoProvider *provider, xmlNode *organization);
+void lasso_provider_set_roles(LassoProvider *provider, LassoProviderRole roles);
 
 #ifdef __cplusplus
 }
