@@ -64,6 +64,7 @@ lasso_server_add_provider_helper(LassoServer *server, LassoProviderRole role,
 {
 	LassoProvider *provider;
 	lasso_error_t rc = 0;
+	LassoProtocolConformance server_conformance, provider_conformance;
 
 	g_return_val_if_fail(LASSO_IS_SERVER(server), LASSO_PARAM_ERROR_BAD_TYPE_OR_NULL_OBJ);
 	g_return_val_if_fail(metadata != NULL, LASSO_PARAM_ERROR_INVALID_VALUE);
@@ -72,13 +73,15 @@ lasso_server_add_provider_helper(LassoServer *server, LassoProviderRole role,
 	goto_cleanup_if_fail_with_rc(provider != NULL, critical_error(LASSO_SERVER_ERROR_ADD_PROVIDER_FAILED));
 
 	provider->role = role;
+	server_conformance = lasso_provider_get_protocol_conformance(LASSO_PROVIDER(server));
+	provider_conformance = lasso_provider_get_protocol_conformance(provider);
 
-	if (LASSO_PROVIDER(server)->private_data->conformance == LASSO_PROTOCOL_SAML_2_0 && provider->private_data->conformance != LASSO_PROTOCOL_SAML_2_0) {
+	if (server_conformance == LASSO_PROTOCOL_SAML_2_0 && provider_conformance != LASSO_PROTOCOL_SAML_2_0)
+	{
 		goto_cleanup_with_rc(LASSO_SERVER_ERROR_ADD_PROVIDER_PROTOCOL_MISMATCH);
 	}
 
-	if (LASSO_PROVIDER(server)->private_data->conformance == LASSO_PROTOCOL_LIBERTY_1_2
-		&& provider->private_data->conformance > LASSO_PROTOCOL_LIBERTY_1_2) {
+	if (server_conformance == LASSO_PROTOCOL_LIBERTY_1_2 && provider_conformance > LASSO_PROTOCOL_LIBERTY_1_2) {
 		goto_cleanup_with_rc(LASSO_SERVER_ERROR_ADD_PROVIDER_PROTOCOL_MISMATCH);
 	}
 
@@ -240,7 +243,7 @@ lasso_server_load_affiliation(LassoServer *server, const gchar *filename)
 	node = xmlDocGetRootElement(doc);
 	goto_cleanup_if_fail_with_rc (node != NULL && node->ns != NULL, LASSO_XML_ERROR_NODE_NOT_FOUND);
 
-	if (provider->private_data->conformance == LASSO_PROTOCOL_SAML_2_0) {
+	if (lasso_provider_get_protocol_conformance(provider) == LASSO_PROTOCOL_SAML_2_0) {
 		rc = lasso_saml20_server_load_affiliation(server, node);
 	} else {
 		/* affiliations are not supported in ID-FF 1.2 mode */
@@ -880,14 +883,14 @@ lasso_server_get_signature_context_for_provider(LassoServer *server,
 		LassoProvider *provider, LassoSignatureContext *signature_context)
 {
 	lasso_error_t rc = 0;
-	LassoSignatureContext *private_context = NULL;
+	const LassoSignatureContext *private_context = NULL;
 
 	lasso_bad_param(SERVER, server);
 	lasso_null_param(signature_context);
 
 	if (provider) {
 		lasso_bad_param(PROVIDER, provider);
-		private_context = &provider->private_data->signature_context;
+		private_context = lasso_provider_get_signature_context(provider);
 	}
 
 	if (private_context && lasso_ok_signature_method(private_context->signature_method)) {
