@@ -43,6 +43,8 @@
 #include <xmlsec/xmltree.h>
 #include <xmlsec/base64.h>
 
+G_DEFINE_TYPE_WITH_PRIVATE(LassoSession, lasso_session, LASSO_TYPE_NODE);
+
 static gboolean lasso_match_name_id(LassoNode *a, LassoNode *b);
 
 struct _NidAndSessionIndex {
@@ -88,7 +90,8 @@ lasso_session_add_nid_and_session_index(LassoSession *session,
 		const char *providerID,
 		struct _NidAndSessionIndex *nid_and_session_index)
 {
-	GList *l = g_hash_table_lookup(session->private_data->nid_and_session_indexes, providerID);
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
+	GList *l = g_hash_table_lookup(private_data->nid_and_session_indexes, providerID);
 	GList *i;
 
 	lasso_foreach(i, l) {
@@ -107,7 +110,7 @@ lasso_session_add_nid_and_session_index(LassoSession *session,
 		l = g_list_append(l, nid_and_session_index);
 	} else {
 		l = g_list_append(l, nid_and_session_index);
-		g_hash_table_insert(session->private_data->nid_and_session_indexes,
+		g_hash_table_insert(private_data->nid_and_session_indexes,
 				g_strdup(providerID), l);
 	}
 }
@@ -231,12 +234,13 @@ lasso_session_get_session_indexes(LassoSession *session,
 {
 	GList *l = NULL, *iter = NULL;
 	GList *ret = NULL;
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
 
 	if (! LASSO_IS_SESSION(session))
 		return NULL;
 	if (! providerID)
 		return NULL;
-	l = g_hash_table_lookup(session->private_data->nid_and_session_indexes,
+	l = g_hash_table_lookup(private_data->nid_and_session_indexes,
 			providerID);
 
 	lasso_foreach(iter, l) {
@@ -268,6 +272,7 @@ lasso_session_get_name_ids(LassoSession *session, const gchar *providerID)
 	GList *nid_and_session_indexes = NULL;
 	GList *ret = NULL;
 	GList *i, *j;
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
 
 	if (! LASSO_IS_SESSION(session))
 		return NULL;
@@ -275,7 +280,7 @@ lasso_session_get_name_ids(LassoSession *session, const gchar *providerID)
 	if (! providerID)
 		return NULL;
 
-	nid_and_session_indexes = g_hash_table_lookup(session->private_data->nid_and_session_indexes,
+	nid_and_session_indexes = g_hash_table_lookup(private_data->nid_and_session_indexes,
 			providerID);
 
 	lasso_foreach(i, nid_and_session_indexes) {
@@ -310,6 +315,7 @@ lasso_session_get_assertion_ids(LassoSession *session, const gchar *providerID)
 	GList *nid_and_session_indexes = NULL;
 	GList *ret = NULL;
 	GList *i;
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
 
 	if (! LASSO_IS_SESSION(session))
 		return NULL;
@@ -317,7 +323,7 @@ lasso_session_get_assertion_ids(LassoSession *session, const gchar *providerID)
 	if (! providerID)
 		return NULL;
 
-	nid_and_session_indexes = g_hash_table_lookup(session->private_data->nid_and_session_indexes,
+	nid_and_session_indexes = g_hash_table_lookup(private_data->nid_and_session_indexes,
 			providerID);
 
 	lasso_foreach(i, nid_and_session_indexes) {
@@ -374,8 +380,9 @@ lasso_session_add_assertion_with_id(LassoSession *session, const char *assertion
 	g_return_val_if_fail(LASSO_IS_SESSION(session), LASSO_PARAM_ERROR_INVALID_VALUE);
 	g_return_val_if_fail(assertionID != NULL, LASSO_PARAM_ERROR_INVALID_VALUE);
 	g_return_val_if_fail(assertion != NULL, LASSO_PARAM_ERROR_INVALID_VALUE);
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
 
-	g_hash_table_insert(session->private_data->assertions_by_id,
+	g_hash_table_insert(private_data->assertions_by_id,
 			g_strdup(assertionID),
 			xmlCopyNode(assertion, 1));
 
@@ -400,8 +407,9 @@ lasso_session_add_status(LassoSession *session, const char *providerID, LassoNod
 	g_return_val_if_fail(LASSO_IS_SESSION(session), LASSO_PARAM_ERROR_INVALID_VALUE);
 	g_return_val_if_fail(providerID != NULL, LASSO_PARAM_ERROR_INVALID_VALUE);
 	g_return_val_if_fail(status != NULL, LASSO_PARAM_ERROR_INVALID_VALUE);
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
 
-	g_hash_table_insert(session->private_data->status, g_strdup(providerID), status);
+	g_hash_table_insert(private_data->status, g_strdup(providerID), status);
 
 	session->is_dirty = TRUE;
 
@@ -443,8 +451,9 @@ xmlNode*
 lasso_session_get_assertion_by_id(LassoSession *session, const gchar *assertionID)
 {
 	g_return_val_if_fail(LASSO_IS_SESSION(session), NULL);
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
 
-	return g_hash_table_lookup(session->private_data->assertions_by_id, assertionID);
+	return g_hash_table_lookup(private_data->assertions_by_id, assertionID);
 }
 
 static void
@@ -499,13 +508,15 @@ lasso_session_get_status(LassoSession *session, const gchar *providerID)
 	if (session == NULL) {
 		return NULL;
 	}
-	return g_hash_table_lookup(session->private_data->status, providerID);
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
+	return g_hash_table_lookup(private_data->status, providerID);
 }
 
 static void
 add_providerID(gchar *key, G_GNUC_UNUSED struct _NidAndSessionIndex *ignored, LassoSession *session)
 {
-	lasso_list_add_string(session->private_data->providerIDs, key);
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
+	lasso_list_add_string(private_data->providerIDs, key);
 }
 
 /**
@@ -525,18 +536,19 @@ lasso_session_get_provider_index(LassoSession *session, gint index)
 	int length;
 
 	g_return_val_if_fail(LASSO_IS_SESSION(session), NULL);
-	g_return_val_if_fail(session->private_data, NULL);
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
+	g_return_val_if_fail(private_data, NULL);
 
-	length = g_hash_table_size(session->private_data->nid_and_session_indexes);
+	length = g_hash_table_size(private_data->nid_and_session_indexes);
 
 	if (length == 0)
 		return NULL;
 
-	if (session->private_data->providerIDs == NULL) {
+	if (private_data->providerIDs == NULL) {
 		lasso_session_init_provider_ids(session);
 	}
 
-	element = g_list_nth(session->private_data->providerIDs, index);
+	element = g_list_nth(private_data->providerIDs, index);
 	if (element == NULL)
 		return NULL;
 
@@ -555,10 +567,11 @@ void
 lasso_session_init_provider_ids(LassoSession *session)
 {
 	g_return_if_fail(LASSO_IS_SESSION(session));
-	g_return_if_fail(session->private_data);
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
+	g_return_if_fail(private_data);
 
-	lasso_release_list_of_strings(session->private_data->providerIDs);
-	g_hash_table_foreach(session->private_data->nid_and_session_indexes, (GHFunc)add_providerID,
+	lasso_release_list_of_strings(private_data->providerIDs);
+	g_hash_table_foreach(private_data->nid_and_session_indexes, (GHFunc)add_providerID,
 			session);
 }
 
@@ -577,11 +590,12 @@ lasso_session_is_empty(LassoSession *session)
 	if (session == NULL) {
 		return TRUE;
 	}
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
 
 	if (g_hash_table_size(session->assertions) +
-	    g_hash_table_size(session->private_data->status) +
-	    g_hash_table_size(session->private_data->assertions_by_id) +
-	    g_hash_table_size(session->private_data->nid_and_session_indexes))
+	    g_hash_table_size(private_data->status) +
+	    g_hash_table_size(private_data->assertions_by_id) +
+	    g_hash_table_size(private_data->nid_and_session_indexes))
 	{
 		return FALSE;
 	}
@@ -605,9 +619,15 @@ lasso_session_count_assertions(LassoSession *session)
 	if (! LASSO_IS_SESSION(session))
 		return -1;
 	if (lasso_flag_thin_sessions)
-		hashtable = session->private_data->nid_and_session_indexes;
+	{
+		LassoSessionPrivate *private_data =
+			lasso_session_get_instance_private(session);
+		hashtable = private_data->nid_and_session_indexes;
+	}
 	else
+	{
 		hashtable = session->assertions;
+	}
 
 	return hashtable ? g_hash_table_size(hashtable) : 0;
 }
@@ -634,12 +654,13 @@ lasso_session_remove_assertion(LassoSession *session, const gchar *providerID)
 {
 	int rc = 0;
 	gboolean ok1, ok2;
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
 
 	lasso_bad_param(SESSION, session);
 	lasso_return_val_if_fail(! lasso_strisempty(providerID), LASSO_PARAM_ERROR_INVALID_VALUE);
 
 	ok1 = g_hash_table_remove(session->assertions, providerID);
-	ok2 = g_hash_table_remove(session->private_data->nid_and_session_indexes, providerID);
+	ok2 = g_hash_table_remove(private_data->nid_and_session_indexes, providerID);
 
 	if (ok1 || ok2) {
 		session->is_dirty = TRUE;
@@ -664,7 +685,9 @@ lasso_session_remove_status(LassoSession *session, const gchar *providerID)
 	g_return_val_if_fail(session != NULL, LASSO_PARAM_ERROR_INVALID_VALUE);
 	g_return_val_if_fail(providerID != NULL, LASSO_PARAM_ERROR_INVALID_VALUE);
 
-	if (g_hash_table_remove(session->private_data->status, providerID)) {
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
+
+	if (g_hash_table_remove(private_data->status, providerID)) {
 		session->is_dirty = TRUE;
 		return 0;
 	}
@@ -770,6 +793,7 @@ get_xmlNode(LassoNode *node, G_GNUC_UNUSED gboolean lasso_dump)
 	xmlNode *xmlnode;
 	LassoSession *session = LASSO_SESSION(node);
 	DumpContext context;
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
 
 	xmlnode = xmlNewNode(NULL, (xmlChar*)"Session");
 	context.parent = xmlnode;
@@ -780,15 +804,15 @@ get_xmlNode(LassoNode *node, G_GNUC_UNUSED gboolean lasso_dump)
 	if (g_hash_table_size(session->assertions))
 		g_hash_table_foreach(session->assertions,
 				(GHFunc)add_assertion_childnode, &context);
-	if (g_hash_table_size(session->private_data->status))
-		g_hash_table_foreach(session->private_data->status,
+	if (g_hash_table_size(private_data->status))
+		g_hash_table_foreach(private_data->status,
 				(GHFunc)add_status_childnode, &context);
-	if (g_hash_table_size(session->private_data->assertions_by_id)) {
-		g_hash_table_foreach(session->private_data->assertions_by_id,
+	if (g_hash_table_size(private_data->assertions_by_id)) {
+		g_hash_table_foreach(private_data->assertions_by_id,
 				(GHFunc)add_assertion_by_id, &context);
 	}
-	if (g_hash_table_size(session->private_data->nid_and_session_indexes)) {
-		g_hash_table_foreach(session->private_data->nid_and_session_indexes,
+	if (g_hash_table_size(private_data->nid_and_session_indexes)) {
+		g_hash_table_foreach(private_data->nid_and_session_indexes,
 				(GHFunc)xmlnode_add_assertion_nid_and_session_indexes, &context);
 	}
 
@@ -906,8 +930,10 @@ init_from_xml(LassoNode *node, xmlNode *xmlnode)
 
 			if (n) {
 				LassoNode *status;
+				LassoSessionPrivate *private_data =
+					lasso_session_get_instance_private(session);
 				status = lasso_node_new_from_xmlNode(n);
-				g_hash_table_insert(session->private_data->status,
+				g_hash_table_insert(private_data->status,
 						xmlGetProp(t, (xmlChar*)"RemoteProviderID"),
 						status);
 			}
@@ -933,16 +959,17 @@ static void
 dispose(GObject *object)
 {
 	LassoSession *session = LASSO_SESSION(object);
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
 
-	if (! session->private_data || session->private_data->dispose_has_run == TRUE)
+	if (! private_data || private_data->dispose_has_run == TRUE)
 		return;
-	session->private_data->dispose_has_run = TRUE;
+	private_data->dispose_has_run = TRUE;
 
 	lasso_release_ghashtable(session->assertions);
-	lasso_release_ghashtable(session->private_data->status);
-	lasso_release_list_of_strings(session->private_data->providerIDs);
-	lasso_release_ghashtable(session->private_data->assertions_by_id);
-	lasso_release_ghashtable(session->private_data->nid_and_session_indexes);
+	lasso_release_ghashtable(private_data->status);
+	lasso_release_list_of_strings(private_data->providerIDs);
+	lasso_release_ghashtable(private_data->assertions_by_id);
+	lasso_release_ghashtable(private_data->nid_and_session_indexes);
 
 	G_OBJECT_CLASS(parent_class)->dispose(object);
 }
@@ -952,28 +979,34 @@ dispose(GObject *object)
 /*****************************************************************************/
 
 static void
-instance_init(LassoSession *session, G_GNUC_UNUSED void *unused)
+lasso_session_init(LassoSession *session)
 {
-	session->private_data = LASSO_SESSION_GET_PRIVATE(session);
-	session->private_data->dispose_has_run = FALSE;
-	session->private_data->providerIDs = NULL;
-	session->private_data->status = g_hash_table_new_full(g_str_hash, g_str_equal,
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
+
+	private_data->dispose_has_run = FALSE;
+	private_data->providerIDs = NULL;
+	private_data->status = g_hash_table_new_full(g_str_hash, g_str_equal,
 			(GDestroyNotify)g_free,
 			(GDestroyNotify)lasso_node_destroy);
-	session->private_data->assertions_by_id =
+	private_data->assertions_by_id =
 			g_hash_table_new_full(g_str_hash, g_str_equal,
 					(GDestroyNotify)g_free,
 					(GDestroyNotify)xmlFree);
 	session->assertions = g_hash_table_new_full(g_str_hash, g_str_equal,
 			(GDestroyNotify)g_free, (GDestroyNotify)lasso_node_destroy);
 	session->is_dirty = FALSE;
-	session->private_data->nid_and_session_indexes = g_hash_table_new_full(g_str_hash,
+	private_data->nid_and_session_indexes = g_hash_table_new_full(g_str_hash,
 			g_str_equal, (GDestroyNotify)g_free,
 			(GDestroyNotify)lasso_release_list_of_nid_an_session_index);
+
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+	session->private_data = private_data;
+#pragma GCC diagnostic pop
 }
 
 static void
-class_init(LassoSessionClass *klass, void *unused G_GNUC_UNUSED)
+lasso_session_class_init(LassoSessionClass *klass)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 	parent_class = g_type_class_peek_parent(klass);
@@ -983,36 +1016,10 @@ class_init(LassoSessionClass *klass, void *unused G_GNUC_UNUSED)
 	nclass->node_data = g_new0(LassoNodeClassData, 1);
 	lasso_node_class_set_nodename(nclass, "Session");
 	lasso_node_class_set_ns(nclass, LASSO_LASSO_HREF, LASSO_LASSO_PREFIX);
-	g_type_class_add_private(nclass, sizeof(LassoSessionPrivate));
 
 	G_OBJECT_CLASS(klass)->dispose = dispose;
 }
 
-GType
-lasso_session_get_type()
-{
-	static GType this_type = 0;
-
-	if (!this_type) {
-		static const GTypeInfo this_info = {
-			sizeof (LassoSessionClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) class_init,
-			NULL,
-			NULL,
-			sizeof(LassoSession),
-			0,
-			(GInstanceInitFunc) instance_init,
-			NULL
-		};
-
-		this_type = g_type_register_static(LASSO_TYPE_NODE,
-				"LassoSession", &this_info, 0);
-	}
-	return this_type;
-}
-
 /**
  * lasso_session_new:
  *
@@ -1081,6 +1088,7 @@ lasso_session_has_slo_session(LassoSession *session, const gchar *provider_id)
 {
 	if (! LASSO_IS_SESSION(session))
 		return FALSE;
-	return g_hash_table_lookup(session->private_data->nid_and_session_indexes, provider_id) !=
+	LassoSessionPrivate *private_data = lasso_session_get_instance_private(session);
+	return g_hash_table_lookup(private_data->nid_and_session_indexes, provider_id) !=
 		NULL;
 }
