@@ -59,7 +59,7 @@ struct _LassoSession {
 	gboolean is_dirty;
 
 	/*< private >*/
-	LassoSessionPrivate *private_data;
+	LassoSessionPrivate *private_data __attribute__ ((deprecated));
 };
 
 struct _LassoSessionClass {
