@@ -43,9 +43,6 @@ struct _LassoSessionPrivate
 	GHashTable *nid_and_session_indexes;
 };
 
-#define LASSO_SESSION_GET_PRIVATE(o) \
-	   (G_TYPE_INSTANCE_GET_PRIVATE ((o), LASSO_TYPE_SESSION, LassoSessionPrivate))
-
 gint lasso_session_add_status(LassoSession *session,
 		const char *providerID, LassoNode *status);
 gint lasso_session_add_assertion_with_id(LassoSession *session,
