@@ -87,7 +87,7 @@ lasso_saml20_login_init_authn_request(LassoLogin *login, LassoHttpMethod http_me
 	login->http_method = login->parent.http_request_method;
 
 	/* save request ID, for later check */
-	lasso_assign_string(login->private_data->request_id, request->ID);
+	lasso_login_set_request_id(login, request->ID);
 	/* set name id policy */
 	lasso_assign_new_gobject(LASSO_SAMLP2_AUTHN_REQUEST(request)->NameIDPolicy,
 			lasso_samlp2_name_id_policy_new());
@@ -917,7 +917,7 @@ lasso_saml20_login_build_assertion(LassoLogin *login,
 
 	response = LASSO_SAMLP2_RESPONSE(profile->response);
 	lasso_list_add_gobject(response->Assertion, assertion);
-	lasso_assign_gobject(login->private_data->saml2_assertion, assertion);
+	lasso_login_set_saml2_assertion(login, assertion);
 cleanup:
 	lasso_release_gobject(assertion);
 	return rc;
@@ -957,7 +957,7 @@ lasso_saml20_login_build_artifact_msg(LassoLogin *login, LassoHttpMethod http_me
 		return critical_error(LASSO_SERVER_ERROR_PROVIDER_NOT_FOUND);
 
 	url = lasso_saml20_login_get_assertion_consumer_service_url(login, remote_provider);
-	assertion = login->private_data->saml2_assertion;
+	assertion = lasso_login_get_saml2_assertion(login);
 	if (LASSO_IS_SAML2_ASSERTION(assertion) && url) {
 		LassoSaml2SubjectConfirmationData *subject_confirmation_data;
 
@@ -976,7 +976,6 @@ lasso_saml20_login_build_artifact_msg(LassoLogin *login, LassoHttpMethod http_me
 				LASSO_NODE(assertion));
 	}
 
-
 	lasso_check_good_rc(lasso_saml20_profile_build_response_msg(profile, NULL, http_method,
 				url));
 
@@ -1049,7 +1048,7 @@ lasso_saml20_login_build_response_msg(LassoLogin *login)
 		assertionConsumerURL = lasso_saml20_provider_get_assertion_consumer_service_url_by_binding(
                          remote_provider, LASSO_SAML2_METADATA_BINDING_PAOS);
 
-		assertion = login->private_data->saml2_assertion;
+		assertion = lasso_login_get_saml2_assertion(login);
 		if (LASSO_IS_SAML2_ASSERTION(assertion) == TRUE) {
 			assertion->Subject->SubjectConfirmation->SubjectConfirmationData->Recipient
 						= g_strdup(assertionConsumerURL);
@@ -1468,10 +1467,11 @@ lasso_saml20_login_process_response_status_and_assertion(LassoLogin *login)
 			LASSO_PROFILE_ERROR_MISSING_SUBJECT);
 
 		/* Verify Subject->SubjectConfirmationData->InResponseTo */
-		if (login->private_data->request_id) {
+		if (lasso_login_get_request_id(login)) {
 			const char *in_response_to = lasso_saml2_assertion_get_in_response_to(assertion);
 
-			if (lasso_strisnotequal(in_response_to,login->private_data->request_id)) {
+			if (lasso_strisnotequal(in_response_to,
+						lasso_login_get_request_id(login))) {
 				rc = LASSO_LOGIN_ERROR_ASSERTION_DOES_NOT_MATCH_REQUEST_ID;
 				goto cleanup;
 			}
@@ -1486,7 +1486,7 @@ lasso_saml20_login_process_response_status_and_assertion(LassoLogin *login)
 
 	/* set the default assertion to the last one */
 	if (last_assertion) {
-		lasso_assign_gobject (login->private_data->saml2_assertion, last_assertion);
+		lasso_login_set_saml2_assertion(login, last_assertion);
 	}
 
 cleanup:
@@ -1573,7 +1573,7 @@ lasso_saml20_login_build_authn_response_msg(LassoLogin *login)
 
 	url = lasso_saml20_login_get_assertion_consumer_service_url(login, remote_provider);
 
-	assertion = login->private_data->saml2_assertion;
+	assertion = lasso_login_get_saml2_assertion(login);
 	if (LASSO_IS_SAML2_ASSERTION(assertion) && url) {
 		LassoSaml2SubjectConfirmationData *subject_confirmation_data;
 
