@@ -66,7 +66,7 @@ static gint lasso_profile_saml20_build_artifact_get_response_msg(LassoProfile *p
 		const char *service);
 static gint lasso_profile_saml20_build_artifact_post_response_msg(LassoProfile *profile,
 		const char *service);
-static char* lasso_saml20_profile_generate_artifact(LassoProfile *profile, int part);
+static const char* lasso_saml20_profile_generate_artifact(LassoProfile *profile, int part);
 
 #define check_msg_body \
 	if (! profile->msg_body) { \
@@ -157,11 +157,11 @@ http_method_to_binding(LassoHttpMethod method) {
  *
  * Return value: the generated artifact (internally allocated, don't free)
  **/
-static char*
+static const char*
 lasso_saml20_profile_generate_artifact(LassoProfile *profile, int part)
 {
 	LassoNode *what = NULL;
-	lasso_assign_new_string(profile->private_data->artifact,
+	lasso_profile_set_new_artifact(profile,
 			lasso_saml20_profile_build_artifact(&profile->server->parent));
 	if (part == 0) {
 		what = profile->request;
@@ -173,10 +173,10 @@ lasso_saml20_profile_generate_artifact(LassoProfile *profile, int part)
 	/* Remove signature at the response level, if needed if will be on the ArtifactResponse */
 	lasso_node_remove_signature(what);
 	/* Keep an XML copy of the response for later retrieval */
-	lasso_assign_new_string(profile->private_data->artifact_message,
+	lasso_profile_set_new_artifact_message(profile,
 			lasso_node_export_to_xml(what));
 
-	return profile->private_data->artifact;
+	return lasso_profile_private_get_artifact(profile);
 }
 
 
@@ -220,7 +220,7 @@ static gint
 lasso_profile_saml20_build_artifact_msg(LassoProfile *profile,
 		const char *url, int request_or_response, int get_or_post)
 {
-	char *artifact = lasso_saml20_profile_generate_artifact(profile, request_or_response);
+	const char *artifact = lasso_saml20_profile_generate_artifact(profile, request_or_response);
 
 	if (artifact == NULL) {
 		return critical_error(LASSO_PROFILE_ERROR_BUILDING_QUERY_FAILED);
@@ -373,7 +373,7 @@ lasso_saml20_profile_process_artifact_resolve(LassoProfile *profile, const char
 	if (! LASSO_IS_SAMLP2_ARTIFACT_RESOLVE(profile->request)) {
 		return critical_error(LASSO_PROFILE_ERROR_INVALID_MSG);
 	}
-	lasso_assign_string(profile->private_data->artifact,
+	lasso_profile_set_artifact(profile,
 			LASSO_SAMLP2_ARTIFACT_RESOLVE(profile->request)->Artifact);
 
 	sig_verify_hint = lasso_profile_get_signature_verify_hint(profile);
@@ -424,10 +424,10 @@ lasso_saml20_profile_build_artifact_response(LassoProfile *profile)
 	response->IssueInstant = lasso_get_current_time();
 	lasso_assign_string(response->InResponseTo, LASSO_SAMLP2_REQUEST_ABSTRACT(profile->request)->ID);
 	/* Add content */
-	if (profile->private_data->artifact_message) {
+	if (lasso_profile_private_get_artifact_message(profile)) {
 		xmlDoc *doc;
 		xmlNode *node;
-		char *content = profile->private_data->artifact_message;
+		const char *content = lasso_profile_private_get_artifact_message(profile);
 		doc = lasso_xml_parse_memory(content, strlen(content));
 		if (doc) {
 			node = xmlDocGetRootElement(doc);
