@@ -203,7 +203,7 @@ load_endpoint_type2(xmlNode *xmlnode, LassoProvider *provider, LassoProviderRole
 	endpoint_type->role = role;
 	endpoint_type->index = idx;
 	endpoint_type->is_default = is_default;
-	lasso_list_add(provider->private_data->endpoints, (void*)endpoint_type);
+	lasso_provider_add_endpoint(provider, endpoint_type);
 
 cleanup:
 	lasso_release_xml_string(binding);
@@ -249,7 +249,6 @@ load_endpoint_type(xmlNode *xmlnode, LassoProvider *provider, LassoProviderRole
 	xmlChar *binding = xmlGetProp(xmlnode, BAD_CAST "Binding");
 	char *name = NULL;
 	char *response_name = NULL;
-	LassoProviderPrivate *private_data = provider->private_data;
 	const char *binding_s = NULL;
 	xmlChar *value = NULL;
 	xmlChar *response_value = NULL;
@@ -273,8 +272,8 @@ load_endpoint_type(xmlNode *xmlnode, LassoProvider *provider, LassoProviderRole
 		xmlChar *index = getSaml2MdProp(xmlnode, LASSO_SAML2_METADATA_ATTRIBUTE_INDEX);
 		xmlChar *is_default = getSaml2MdProp(xmlnode, LASSO_SAML2_METADATA_ATTRIBUTE_ISDEFAULT);
 
-		if (xsdIsTrue(is_default) && ! private_data->default_assertion_consumer) {
-			lasso_assign_string(private_data->default_assertion_consumer, (char*)index);
+		if (xsdIsTrue(is_default) && ! lasso_provider_get_default_assertion_consumer(provider)) {
+			lasso_provider_set_default_assertion_consumer(provider, (char*)index);
 		}
 		name = g_strdup_printf(LASSO_SAML2_METADATA_ELEMENT_ASSERTION_CONSUMER_SERVICE 
 				" %s %s", 
@@ -314,10 +313,9 @@ load_default_assertion_consumer(xmlNode *descriptor, LassoProvider *provider)
 	xmlChar *index = NULL;
 	xmlChar *is_default = NULL;
 	xmlNode *t = NULL;
-	LassoProviderPrivate *pdata = provider->private_data;
 
-	g_return_val_if_fail(pdata, FALSE);
-	if (provider->private_data->default_assertion_consumer) {
+	g_return_val_if_fail(lasso_provider_is_init(provider), FALSE);
+	if(lasso_provider_get_default_assertion_consumer(provider)) {
 		return TRUE;
 	}
 
@@ -333,7 +331,7 @@ load_default_assertion_consumer(xmlNode *descriptor, LassoProvider *provider)
 					t = xmlSecGetNextElementNode(t->next);
 					continue;
 				}
-				lasso_assign_string(pdata->default_assertion_consumer, (char*)index);
+				lasso_provider_set_default_assertion_consumer(provider, (char*)index);
 				lasso_release_xml_string(index);
 				break;
 			}
@@ -341,7 +339,7 @@ load_default_assertion_consumer(xmlNode *descriptor, LassoProvider *provider)
 		t = xmlSecGetNextElementNode(t->next);
 	}
 	lasso_release_xml_string(is_default);
-	if (provider->private_data->default_assertion_consumer) {
+	if (lasso_provider_get_default_assertion_consumer(provider)) {
 		return TRUE;
 	}
 	t = xmlSecFindChild(descriptor,
@@ -354,7 +352,7 @@ load_default_assertion_consumer(xmlNode *descriptor, LassoProvider *provider)
 	if (! index) {
 		return FALSE;
 	}
-	lasso_assign_string( pdata->default_assertion_consumer, (char*)index);
+	lasso_provider_set_default_assertion_consumer(provider, (char*)index);
 	lasso_release_xml_string(index);
 	return TRUE;
 
@@ -374,7 +372,6 @@ load_descriptor(xmlNode *xmlnode, LassoProvider *provider, LassoProviderRole rol
 	int i;
 	xmlNode *t;
 	xmlChar *value;
-	LassoProviderPrivate *pdata = provider->private_data;
 	char *token, *saveptr = NULL;
 	int counter = 0;
 	
@@ -394,7 +391,8 @@ load_descriptor(xmlNode *xmlnode, LassoProvider *provider, LassoProviderRole rol
 	lasso_release_xml_string(value);
 
 	/* add role to supported roles for the provider */
-	pdata->roles |= role;
+	lasso_provider_set_roles(provider,
+			lasso_provider_get_roles(provider) | role);
 	t = xmlSecGetNextElementNode(xmlnode->children);
 	while (t) {
 		if (checkSaml2MdNode(t,
@@ -404,8 +402,7 @@ load_descriptor(xmlNode *xmlnode, LassoProvider *provider, LassoProviderRole rol
 					LASSO_SAML2_ASSERTION_ELEMENT_ATTRIBUTE) && role == LASSO_PROVIDER_ROLE_IDP) {
 			LassoSaml2Attribute *attribute;
 			attribute = (LassoSaml2Attribute*) lasso_node_new_from_xmlNode(t);
-			lasso_list_add_new_gobject(pdata->attributes, 
-					attribute);
+			lasso_provider_add_attribute(provider, attribute);
 		} else if (hasSaml2MdProp(t, LASSO_SAML2_METADATA_ATTRIBUTE_BINDING)) {
 			load_endpoint_type(t, provider, role);
 			load_endpoint_type2(t, provider, role, &counter);
@@ -417,8 +414,7 @@ load_descriptor(xmlNode *xmlnode, LassoProvider *provider, LassoProviderRole rol
 		}
 		t = xmlSecGetNextElementNode(t->next);
 	}
-	provider->private_data->endpoints = g_list_sort(provider->private_data->endpoints,
-			(GCompareFunc) compare_endpoint_type);
+	lasso_provider_sort_endpoints(provider, (GCompareFunc)compare_endpoint_type);
 	for (i = 0; descriptor_attrs[i]; i++) {
 		value = getSaml2MdProp(xmlnode, descriptor_attrs[i]);
 		if (value == NULL) {
@@ -446,7 +442,6 @@ lasso_saml20_provider_load_metadata(LassoProvider *provider, xmlNode *root_node)
 	xmlChar *providerID;
 	xmlChar providerID_cpy[150] = "";
 
-	LassoProviderPrivate *pdata = provider->private_data;
 	static const struct {
 		char *name;
 		LassoProviderRole role;
@@ -485,13 +480,17 @@ lasso_saml20_provider_load_metadata(LassoProvider *provider, xmlNode *root_node)
 	g_strlcpy((char*) providerID_cpy, (char*) providerID, 150);
 	lasso_release_xml_string(providerID);
 	/* initialize roles */
-	pdata->roles = LASSO_PROVIDER_ROLE_NONE;
-	lasso_set_string_from_prop(&pdata->valid_until, node,
-				BAD_CAST LASSO_SAML2_METADATA_ATTRIBUTE_VALID_UNTIL,
-				BAD_CAST LASSO_SAML2_METADATA_HREF);
-	lasso_set_string_from_prop(&pdata->cache_duration, node,
-				BAD_CAST LASSO_SAML2_METADATA_ATTRIBUTE_CACHE_DURATION,
-				BAD_CAST LASSO_SAML2_METADATA_HREF);
+	lasso_provider_set_roles(provider, LASSO_PROVIDER_ROLE_NONE);
+	lasso_provider_set_valid_until_from_prop(
+		provider,
+		node,
+		BAD_CAST LASSO_SAML2_METADATA_ATTRIBUTE_VALID_UNTIL,
+		BAD_CAST LASSO_SAML2_METADATA_HREF);
+	lasso_provider_set_cache_duration_from_prop(
+		provider,
+		node,
+		BAD_CAST LASSO_SAML2_METADATA_ATTRIBUTE_CACHE_DURATION,
+		BAD_CAST LASSO_SAML2_METADATA_HREF);
 
 	descriptor_node = xmlSecGetNextElementNode(node->children);
 	while (descriptor_node) {
@@ -511,19 +510,23 @@ lasso_saml20_provider_load_metadata(LassoProvider *provider, xmlNode *root_node)
 		}
 
 		if (checkSaml2MdNode(descriptor_node,
-					LASSO_SAML2_METADATA_ELEMENT_ORGANIZATION)) {
-			lasso_assign_xml_node(pdata->organization, descriptor_node); }
+					LASSO_SAML2_METADATA_ELEMENT_ORGANIZATION))
+		{
+			lasso_provider_set_organization(provider, descriptor_node);
+		}
 		descriptor_node = xmlSecGetNextElementNode(descriptor_node->next);
 	}
 
 	if (! LASSO_IS_SERVER(provider) &&
-			(! loaded_one_or_more_descriptor || (pdata->roles & provider->role) == 0)) {
+			(! loaded_one_or_more_descriptor || \
+			 (lasso_provider_get_roles(provider) & provider->role) == 0)
+			) {
 		/* We must at least load one descriptor, and we must load a descriptor for our
 		 * assigned role or we fail. */
 		if (! loaded_one_or_more_descriptor) {
 			warning("%s: No descriptor was loaded, failing", providerID_cpy);
 		}
-		if ((pdata->roles & provider->role) == 0) {
+		if ((lasso_provider_get_roles(provider) & provider->role) == 0) {
 			warning("%s: Loaded roles and prescribed role does not intersect",
 					providerID_cpy);
 		}
@@ -552,7 +555,7 @@ enum {
 static gboolean has_synchronous_methods(LassoProvider *provider, LassoMdProtocolType protocol_type,
 		gboolean for_response)
 {
-	GList *t = NULL;
+	const GList *t = NULL;
 	const char *kind = NULL;
 	LassoHttpMethod result = LASSO_HTTP_METHOD_NONE;
 
@@ -568,7 +571,7 @@ static gboolean has_synchronous_methods(LassoProvider *provider, LassoMdProtocol
 		kind = LASSO_SAML2_METADATA_ELEMENT_ASSERTION_CONSUMER_SERVICE;
 	}
 
-	lasso_foreach(t, provider->private_data->endpoints) {
+	lasso_foreach(t, lasso_provider_get_endpoints(provider)) {
 		EndpointType *endpoint_type = (EndpointType*)t->data;
 		if (endpoint_type && lasso_strisequal(endpoint_type->kind, kind)) {
 			result = binding_uri_to_http_method(endpoint_type->binding);
@@ -584,7 +587,7 @@ LassoHttpMethod
 lasso_saml20_provider_get_first_http_method(LassoProvider *provider,
 		LassoProvider *remote_provider, LassoMdProtocolType protocol_type)
 {
-	GList *t = NULL;
+	const GList *t = NULL;
 	const char *kind = NULL;
 	LassoHttpMethod result = LASSO_HTTP_METHOD_NONE;
 	
@@ -595,7 +598,7 @@ lasso_saml20_provider_get_first_http_method(LassoProvider *provider,
 		return LASSO_HTTP_METHOD_NONE;
 	}
 
-	lasso_foreach(t, remote_provider->private_data->endpoints) {
+	lasso_foreach(t, lasso_provider_get_endpoints(remote_provider)) {
 		EndpointType *endpoint_type = (EndpointType*)t->data;
 		if (endpoint_type && lasso_strisequal(endpoint_type->kind, kind)) {
 			result = binding_uri_to_http_method(endpoint_type->binding);
@@ -617,7 +620,7 @@ lasso_saml20_provider_accept_http_method(G_GNUC_UNUSED LassoProvider *provider,
 		LassoMdProtocolType protocol_type, LassoHttpMethod http_method,
 		G_GNUC_UNUSED gboolean initiate_profile)
 {
-	GList *t = NULL;
+	const GList *t = NULL;
 	const char *kind = NULL;
 	
 	if (protocol_type < LASSO_MD_PROTOCOL_TYPE_LAST) {
@@ -628,7 +631,7 @@ lasso_saml20_provider_accept_http_method(G_GNUC_UNUSED LassoProvider *provider,
 		return FALSE;
 	}
 
-	lasso_foreach(t, remote_provider->private_data->endpoints) {
+	lasso_foreach(t, lasso_provider_get_endpoints(remote_provider)) {
 		EndpointType *endpoint_type = (EndpointType*)t->data;
 		if (endpoint_type && endpoint_type->role == remote_provider->role &&
 				lasso_strisequal(endpoint_type->kind, kind)) {
@@ -644,9 +647,9 @@ lasso_saml20_provider_accept_http_method(G_GNUC_UNUSED LassoProvider *provider,
 gboolean
 lasso_saml20_provider_check_assertion_consumer_service_url(LassoProvider *provider, const gchar *url, const gchar *binding)
 {
-	GList *t = NULL;
+	const GList *t = NULL;
 
-	lasso_foreach (t, provider->private_data->endpoints) {
+	lasso_foreach(t, lasso_provider_get_endpoints(provider)) {
 		EndpointType *endpoint_type = (EndpointType*) t->data;
 		if (endpoint_type && endpoint_type->role == LASSO_PROVIDER_ROLE_SP
 				&& lasso_strisequal(endpoint_type->url,url)
@@ -677,11 +680,11 @@ static EndpointType *
 lasso_saml20_provider_get_assertion_consumer_service(LassoProvider *provider, int service_id)
 {
 	const char *kind = LASSO_SAML2_METADATA_ELEMENT_ASSERTION_CONSUMER_SERVICE;
-	GList *t = NULL;
+	const GList *t = NULL;
 	EndpointType *result = NULL;
 
 	if (service_id != -1) {
-		lasso_foreach(t, provider->private_data->endpoints) {
+		lasso_foreach(t, lasso_provider_get_endpoints(provider)) {
 			EndpointType *endpoint_type = (EndpointType*) t->data;
 			if (! endpoint_type)
 				continue;
@@ -694,7 +697,7 @@ lasso_saml20_provider_get_assertion_consumer_service(LassoProvider *provider, in
 			}
 		}
 	} else { /* lookup a default supported endpoint type */
-		lasso_foreach(t, provider->private_data->endpoints) {
+		lasso_foreach(t, lasso_provider_get_endpoints(provider)) {
 			EndpointType *endpoint_type = (EndpointType*) t->data;
 			if (! endpoint_type)
 				continue;
@@ -740,9 +743,9 @@ const gchar*
 lasso_saml20_provider_get_assertion_consumer_service_binding_by_url(LassoProvider *provider, const char *url)
 {
 	const char *kind = LASSO_SAML2_METADATA_ELEMENT_ASSERTION_CONSUMER_SERVICE;
-	GList *t = NULL;
+	const GList *t = NULL;
 
-	lasso_foreach(t, provider->private_data->endpoints) {
+	lasso_foreach(t, lasso_provider_get_endpoints(provider)) {
 		EndpointType *endpoint_type = (EndpointType*) t->data;
 		if (! endpoint_type)
 			continue;
@@ -761,9 +764,9 @@ lasso_saml20_provider_get_assertion_consumer_service_url_by_binding(LassoProvide
 		const gchar *binding)
 {
 	const char *kind = LASSO_SAML2_METADATA_ELEMENT_ASSERTION_CONSUMER_SERVICE;
-	GList *t = NULL;
+	const GList *t = NULL;
 
-	lasso_foreach(t, provider->private_data->endpoints) {
+	lasso_foreach(t, lasso_provider_get_endpoints(provider)) {
 		EndpointType *endpoint_type = (EndpointType*) t->data;
 		if (! endpoint_type)
 			continue;
@@ -795,11 +798,11 @@ lasso_saml20_provider_get_endpoint_url(LassoProvider *provider,
 		gboolean is_default, int idx)
 {
 	EndpointType* endpoint_type = NULL;
-	GList *t = NULL;
+	const GList *t = NULL;
 
 	if (! LASSO_IS_PROVIDER(provider) || !kind)
 		return NULL;
-	lasso_foreach(t, provider->private_data->endpoints) {
+	lasso_foreach(t, lasso_provider_get_endpoints(provider)) {
 		endpoint_type = (EndpointType*) t->data;
 		if (! endpoint_type)
 			continue;
@@ -840,11 +843,11 @@ lasso_error_t
 lasso_saml20_provider_get_artifact_resolution_service_index(LassoProvider *provider, unsigned short *index)
 {
 	const char *kind = LASSO_SAML2_METADATA_ELEMENT_ARTIFACT_RESOLUTION_SERVICE;
-	GList *t = NULL;
+	const GList *t = NULL;
 
 	lasso_bad_param(PROVIDER, provider)
 	lasso_null_param(index);
-	lasso_foreach(t, provider->private_data->endpoints) {
+	lasso_foreach(t, lasso_provider_get_endpoints(provider)) {
 		EndpointType *endpoint_type = (EndpointType*) t->data;
 		if (! endpoint_type)
 			continue;
