@@ -731,6 +731,10 @@ inline static gboolean
 lasso_xmlstrisnotequal(const xmlChar *a, const xmlChar *b) {
 	return lasso_strisnotequal((char*)a, (char*)b);
 }
+inline static gboolean
+lasso_strstartswith(const char *str, const char *needle) {
+	return strncmp(str, needle, strlen(needle)) == 0;
+}
 
 /**
  * lasso_crypto_memequal:
