@@ -30,14 +30,11 @@
  *
  */
 
-struct _LassoDsKeyValuePrivate {
+typedef struct {
 	LassoDsX509Data *X509Data;
-};
+} LassoDsKeyValuePrivate;
 
-typedef struct _LassoDsKeyValuePrivate LassoDsKeyValuePrivate;
-
-#define LASSO_DS_KEY_VALUE_GET_PRIVATE(o) \
-	   (G_TYPE_INSTANCE_GET_PRIVATE ((o), LASSO_TYPE_DS_KEY_VALUE, LassoDsKeyValuePrivate))
+G_DEFINE_TYPE_WITH_PRIVATE(LassoDsKeyValue, lasso_ds_key_value, LASSO_TYPE_NODE);
 
 /*****************************************************************************/
 /* private methods                                                           */
@@ -55,7 +52,7 @@ static struct XmlSnippet schema_snippets[] = {
 
 
 static void
-class_init(LassoDsKeyValueClass *klass, void *unused G_GNUC_UNUSED)
+lasso_ds_key_value_class_init(LassoDsKeyValueClass *klass)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
@@ -63,33 +60,11 @@ class_init(LassoDsKeyValueClass *klass, void *unused G_GNUC_UNUSED)
 	lasso_node_class_set_nodename(nclass, "KeyValue");
 	lasso_node_class_set_ns(nclass, LASSO_DS_HREF, LASSO_DS_PREFIX);
 	lasso_node_class_add_snippets(nclass, schema_snippets);
-	g_type_class_add_private(klass, sizeof(LassoDsKeyValuePrivate));
 }
 
-GType
-lasso_ds_key_value_get_type()
-{
-	static GType this_type = 0;
-
-	if (!this_type) {
-		static const GTypeInfo this_info = {
-			sizeof (LassoDsKeyValueClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) class_init,
-			NULL,
-			NULL,
-			sizeof(LassoDsKeyValue),
-			0,
-			NULL,
-			NULL
-		};
-
-		this_type = g_type_register_static(LASSO_TYPE_NODE,
-				"LassoDsKeyValue", &this_info, 0);
-	}
-	return this_type;
-}
+static void
+lasso_ds_key_value_init(LassoDsKeyValue* self)
+{}
 
 /**
  * lasso_ds_key_value_new:
@@ -116,7 +91,9 @@ lasso_ds_key_value_get_x509_data(LassoDsKeyValue *key_value)
 {
 	lasso_return_val_if_fail(LASSO_IS_DS_KEY_VALUE(key_value), NULL);
 
-	return LASSO_DS_KEY_VALUE_GET_PRIVATE(key_value)->X509Data;
+	LassoDsKeyValuePrivate *private_data =
+		lasso_ds_key_value_get_instance_private(key_value);
+	return private_data->X509Data;
 }
 
 /**
@@ -130,5 +107,7 @@ lasso_ds_key_value_set_x509_data(LassoDsKeyValue *key_value, LassoDsX509Data *x5
 {
 	lasso_return_if_fail(LASSO_IS_DS_KEY_VALUE(key_value));
 
-	lasso_assign_gobject(LASSO_DS_KEY_VALUE_GET_PRIVATE(key_value)->X509Data, x509_data);
+	LassoDsKeyValuePrivate *private_data =
+		lasso_ds_key_value_get_instance_private(key_value);
+	lasso_assign_gobject(private_data->X509Data, x509_data);
 }
