@@ -59,13 +59,12 @@
 /* private methods                                                           */
 /*****************************************************************************/
 
-#define LASSO_LIB_LOGOUT_REQUEST_GET_PRIVATE(o) \
-	   (G_TYPE_INSTANCE_GET_PRIVATE ((o), LASSO_TYPE_LIB_LOGOUT_REQUEST, \
-					 struct _LassoLibLogoutRequestPrivate))
-
-struct _LassoLibLogoutRequestPrivate {
+typedef struct {
 	GList *SessionIndex;
-};
+} LassoLibLogoutRequestPrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE(LassoLibLogoutRequest, lasso_lib_logout_request,
+		LASSO_TYPE_SAMLP_REQUEST_ABSTRACT);
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "Extension", SNIPPET_EXTENSION, G_STRUCT_OFFSET(LassoLibLogoutRequest, Extension), NULL, NULL, NULL},
@@ -73,8 +72,8 @@ static struct XmlSnippet schema_snippets[] = {
 	{ "NameIdentifier", SNIPPET_NODE, G_STRUCT_OFFSET(LassoLibLogoutRequest, NameIdentifier),
 		NULL, LASSO_SAML_ASSERTION_PREFIX, LASSO_SAML_ASSERTION_HREF},
 	{ "SessionIndex", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoLibLogoutRequest, SessionIndex), NULL, NULL, NULL},
-	{ "SessionIndex", SNIPPET_LIST_CONTENT|SNIPPET_PRIVATE, G_STRUCT_OFFSET(struct
-			_LassoLibLogoutRequestPrivate, SessionIndex), NULL, NULL, NULL},
+	{ "SessionIndex", SNIPPET_LIST_CONTENT|SNIPPET_PRIVATE, G_STRUCT_OFFSET(
+			LassoLibLogoutRequestPrivate, SessionIndex), NULL, NULL, NULL},
 	{ "RelayState", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoLibLogoutRequest, RelayState), NULL, NULL, NULL},
 	{ "consent", SNIPPET_ATTRIBUTE, G_STRUCT_OFFSET(LassoLibLogoutRequest, consent), NULL, NULL, NULL},
 	{ "NotOnOrAfter", SNIPPET_ATTRIBUTE,
@@ -134,7 +133,7 @@ cleanup:
 
 
 static void
-class_init(LassoLibLogoutRequestClass *klass, void *unused G_GNUC_UNUSED)
+lasso_lib_logout_request_class_init(LassoLibLogoutRequestClass *klass)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
@@ -145,33 +144,11 @@ class_init(LassoLibLogoutRequestClass *klass, void *unused G_GNUC_UNUSED)
 	lasso_node_class_set_ns(nclass, LASSO_LIB_HREF, LASSO_LIB_PREFIX);
 	lasso_node_class_add_snippets(nclass, schema_snippets);
 	lasso_node_class_add_query_snippets(nclass, query_snippets);
-	g_type_class_add_private(nclass, sizeof(struct _LassoLibLogoutRequestPrivate));
 }
 
-GType
-lasso_lib_logout_request_get_type()
-{
-	static GType this_type = 0;
-
-	if (!this_type) {
-		static const GTypeInfo this_info = {
-			sizeof (LassoLibLogoutRequestClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) class_init,
-			NULL,
-			NULL,
-			sizeof(LassoLibLogoutRequest),
-			0,
-			NULL,
-			NULL
-		};
-
-		this_type = g_type_register_static(LASSO_TYPE_SAMLP_REQUEST_ABSTRACT,
-				"LassoLibLogoutRequest", &this_info, 0);
-	}
-	return this_type;
-}
+static void
+lasso_lib_logout_request_init(LassoLibLogoutRequest *self)
+{}
 
 /**
  * lasso_lib_logout_request_new:
@@ -231,11 +208,11 @@ lasso_lib_logout_request_set_session_indexes(LassoLibLogoutRequest *lib_logout_r
 		GList *session_indexes)
 {
 	char *first = NULL;
-	struct _LassoLibLogoutRequestPrivate *private_data;
+	LassoLibLogoutRequestPrivate *private_data;
 
 	if (! LASSO_IS_LIB_LOGOUT_REQUEST(lib_logout_request))
 		return;
-	private_data = LASSO_LIB_LOGOUT_REQUEST_GET_PRIVATE(lib_logout_request);
+	private_data = lasso_lib_logout_request_get_instance_private(lib_logout_request);
 	if (session_indexes) {
 		first = session_indexes->data;
 		session_indexes = g_list_next(session_indexes);
@@ -256,13 +233,13 @@ lasso_lib_logout_request_set_session_indexes(LassoLibLogoutRequest *lib_logout_r
 GList*
 lasso_lib_logout_request_get_session_indexes(LassoLibLogoutRequest *lib_logout_request)
 {
-	struct _LassoLibLogoutRequestPrivate *private_data;
+	LassoLibLogoutRequestPrivate *private_data;
 	GList *ret = NULL;
 	GList *i = NULL;
 
 	if (! LASSO_IS_LIB_LOGOUT_REQUEST(lib_logout_request))
 		return NULL;
-	private_data = LASSO_LIB_LOGOUT_REQUEST_GET_PRIVATE(lib_logout_request);
+	private_data = lasso_lib_logout_request_get_instance_private(lib_logout_request);
 	if (lib_logout_request->SessionIndex) {
 		lasso_list_add_string(ret, lib_logout_request->SessionIndex);
 	}
