@@ -75,7 +75,7 @@ static LassoNodeClass *parent_class = NULL;
 
 
 static void
-class_init(LassoSaml2ConditionsClass *klass)
+class_init(LassoSaml2ConditionsClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
