@@ -50,10 +50,13 @@
  * </figure>
  */
 
-struct _LassoSaml2SubjectConfirmationDataPrivate {
+typedef struct {
 	GList *any;
 	GHashTable *attributes;
-};
+} LassoSaml2SubjectConfirmationDataPrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE(LassoSaml2SubjectConfirmationData,
+		lasso_saml2_subject_confirmation_data, LASSO_TYPE_NODE);
 
 /*****************************************************************************/
 /* private methods                                                           */
@@ -72,9 +75,9 @@ static struct XmlSnippet schema_snippets[] = {
 	{ "Address", SNIPPET_ATTRIBUTE,
 		G_STRUCT_OFFSET(LassoSaml2SubjectConfirmationData, Address), NULL, NULL, NULL},
 	{ "", SNIPPET_LIST_NODES | SNIPPET_ANY | SNIPPET_PRIVATE,
-		G_STRUCT_OFFSET(struct _LassoSaml2SubjectConfirmationDataPrivate, any), NULL, NULL, NULL},
+		G_STRUCT_OFFSET(LassoSaml2SubjectConfirmationDataPrivate, any), NULL, NULL, NULL},
 	{ "", SNIPPET_ATTRIBUTE | SNIPPET_ANY | SNIPPET_PRIVATE,
-		G_STRUCT_OFFSET(struct _LassoSaml2SubjectConfirmationDataPrivate, attributes), NULL, NULL, NULL},
+		G_STRUCT_OFFSET(LassoSaml2SubjectConfirmationDataPrivate, attributes), NULL, NULL, NULL},
 	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
@@ -87,7 +90,7 @@ static LassoNodeClass *parent_class = NULL;
 
 
 static void
-class_init(LassoSaml2SubjectConfirmationDataClass *klass, void *unused G_GNUC_UNUSED)
+lasso_saml2_subject_confirmation_data_class_init(LassoSaml2SubjectConfirmationDataClass *klass)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
@@ -96,33 +99,11 @@ class_init(LassoSaml2SubjectConfirmationDataClass *klass, void *unused G_GNUC_UN
 	lasso_node_class_set_nodename(nclass, "SubjectConfirmationData");
 	lasso_node_class_set_ns(nclass, LASSO_SAML2_ASSERTION_HREF, LASSO_SAML2_ASSERTION_PREFIX);
 	lasso_node_class_add_snippets(nclass, schema_snippets);
-	g_type_class_add_private(klass, sizeof(struct _LassoSaml2SubjectConfirmationDataPrivate));
 }
 
-GType
-lasso_saml2_subject_confirmation_data_get_type()
-{
-	static GType this_type = 0;
-
-	if (!this_type) {
-		static const GTypeInfo this_info = {
-			sizeof (LassoSaml2SubjectConfirmationDataClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) class_init,
-			NULL,
-			NULL,
-			sizeof(LassoSaml2SubjectConfirmationData),
-			0,
-			NULL,
-			NULL
-		};
-
-		this_type = g_type_register_static(LASSO_TYPE_NODE,
-				"LassoSaml2SubjectConfirmationData", &this_info, 0);
-	}
-	return this_type;
-}
+static void
+lasso_saml2_subject_confirmation_data_init(LassoSaml2SubjectConfirmationData *unused G_GNUC_UNUSED)
+{}
 
 /**
  * lasso_saml2_subject_confirmation_data_new:
