@@ -54,11 +54,12 @@
  * </figure>
  */
 
-typedef struct _LassoSamlp2LogoutRequestPrivate LassoSamlp2LogoutRequestPrivate;
-
-struct _LassoSamlp2LogoutRequestPrivate {
+typedef struct {
 	GList *SessionIndex;
-};
+} LassoSamlp2LogoutRequestPrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE(LassoSamlp2LogoutRequest, lasso_samlp2_logout_request,
+		LASSO_TYPE_SAMLP2_REQUEST_ABSTRACT);
 
 /*****************************************************************************/
 /* private methods                                                           */
@@ -87,16 +88,13 @@ static LassoNodeClass *parent_class = NULL;
 
 #define SESSION_INDEX "SessionIndex"
 
-#define GET_PRIVATE(x) G_TYPE_INSTANCE_GET_PRIVATE(x, \
-		LASSO_TYPE_SAMLP2_LOGOUT_REQUEST, LassoSamlp2LogoutRequestPrivate)
-
 static void
 dispose(GObject *object)
 {
 	LassoSamlp2LogoutRequest *logout_request = LASSO_SAMLP2_LOGOUT_REQUEST(object);
 	LassoSamlp2LogoutRequestPrivate *pv;
 
-	pv = GET_PRIVATE(logout_request);
+	pv = lasso_samlp2_logout_request_get_instance_private(logout_request);
 	lasso_release_list_of_strings(pv->SessionIndex);
 	G_OBJECT_CLASS(parent_class)->dispose(G_OBJECT(logout_request));
 }
@@ -128,14 +126,10 @@ get_xmlNode(LassoNode *node, gboolean lasso_dump)
 	lasso_foreach(it, other_session_index) {
 		xmlNode *child = xmlSecAddChild(xmlnode, BAD_CAST SESSION_INDEX,
 				BAD_CAST LASSO_SAML2_PROTOCOL_HREF);
-#if (XMLSEC_MAJOR > 1) || (XMLSEC_MAJOR == 1 && XMLSEC_MINOR > 2) || (XMLSEC_MAJOR == 1 && XMLSEC_MINOR == 2 && XMLSEC_SUBMINOR > 12)
-		xmlSecNodeEncodeAndSetContent(child, BAD_CAST it->data);
-#else
 		xmlChar *content;
 		content = xmlEncodeSpecialChars(child->doc, BAD_CAST it->data);
 		xmlNodeSetContent(child, content);
 		xmlFree(content);
-#endif
 	}
 	((LassoSamlp2LogoutRequest*)node)->SessionIndex = keep_session_index;
 	lasso_release_list_of_strings(other_session_index);
@@ -161,7 +155,8 @@ init_from_xml(LassoNode *node, xmlNode *xmlnode)
 
 	if (rc == 0) {
 
-		pv = GET_PRIVATE(node);
+		pv = lasso_samlp2_logout_request_get_instance_private(
+				LASSO_SAMLP2_LOGOUT_REQUEST(node));
 		child = xmlSecFindChild(xmlnode, BAD_CAST SESSION_INDEX,
 				BAD_CAST LASSO_SAML2_PROTOCOL_HREF);
 		while (child && xmlSecCheckNodeName(child, BAD_CAST SESSION_INDEX,
@@ -182,7 +177,7 @@ init_from_xml(LassoNode *node, xmlNode *xmlnode)
 }
 
 static void
-class_init(LassoSamlp2LogoutRequestClass *klass, void *unused G_GNUC_UNUSED)
+lasso_samlp2_logout_request_class_init(LassoSamlp2LogoutRequestClass *klass)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
@@ -193,34 +188,12 @@ class_init(LassoSamlp2LogoutRequestClass *klass, void *unused G_GNUC_UNUSED)
 	lasso_node_class_set_nodename(nclass, "LogoutRequest");
 	lasso_node_class_set_ns(nclass, LASSO_SAML2_PROTOCOL_HREF, LASSO_SAML2_PROTOCOL_PREFIX);
 	lasso_node_class_add_snippets(nclass, schema_snippets);
-	g_type_class_add_private(G_OBJECT_CLASS(klass), sizeof(LassoSamlp2LogoutRequestPrivate));
 	G_OBJECT_CLASS(klass)->dispose = dispose;
 }
 
-GType
-lasso_samlp2_logout_request_get_type()
-{
-	static GType this_type = 0;
-
-	if (!this_type) {
-		static const GTypeInfo this_info = {
-			sizeof (LassoSamlp2LogoutRequestClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) class_init,
-			NULL,
-			NULL,
-			sizeof(LassoSamlp2LogoutRequest),
-			0,
-			NULL,
-			NULL
-		};
-
-		this_type = g_type_register_static(LASSO_TYPE_SAMLP2_REQUEST_ABSTRACT,
-				"LassoSamlp2LogoutRequest", &this_info, 0);
-	}
-	return this_type;
-}
+static void
+lasso_samlp2_logout_request_init(LassoSamlp2LogoutRequest* self)
+{}
 
 /**
  * lasso_samlp2_logout_request_get_session_indexes:
@@ -240,7 +213,7 @@ lasso_samlp2_logout_request_get_session_indexes(LassoSamlp2LogoutRequest *logout
 	g_return_val_if_fail(LASSO_IS_SAMLP2_LOGOUT_REQUEST(logout_request), NULL);
 
 	/* Return concatenation of old field + new private field */
-	pv = GET_PRIVATE(logout_request);
+	pv = lasso_samlp2_logout_request_get_instance_private(logout_request);
 	lasso_assign_list_of_strings(ret, pv->SessionIndex);
 	if (logout_request->SessionIndex) {
 		ret = g_list_prepend(ret, g_strdup(logout_request->SessionIndex));
@@ -267,7 +240,7 @@ lasso_samlp2_logout_request_set_session_indexes(LassoSamlp2LogoutRequest *logout
 	g_return_if_fail(LASSO_IS_SAMLP2_LOGOUT_REQUEST(logout_request));
 
 	/* assign rest of the list to the new private field */
-	pv = GET_PRIVATE(logout_request);
+	pv = lasso_samlp2_logout_request_get_instance_private(logout_request);
 	if (! session_index) {
 		lasso_release_string(logout_request->SessionIndex);
 		lasso_release_list_of_strings(pv->SessionIndex);
