@@ -65,7 +65,7 @@ static struct XmlSnippet schema_snippets[] = {
 
 
 static void
-class_init(LassoSamlp2NameIDMappingResponseClass *klass)
+class_init(LassoSamlp2NameIDMappingResponseClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
