@@ -122,13 +122,13 @@ init_from_query(LassoNode *node, char **query_fields)
 /*****************************************************************************/
 
 static void
-instance_init(LassoSamlp2StatusResponse *node)
+instance_init(LassoSamlp2StatusResponse *node, G_GNUC_UNUSED void *unused)
 {
 	node->sign_type = LASSO_SIGNATURE_TYPE_NONE;
 }
 
 static void
-class_init(LassoSamlp2StatusResponseClass *klass)
+class_init(LassoSamlp2StatusResponseClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
