@@ -52,7 +52,7 @@
 /*****************************************************************************/
 
 static struct XmlSnippet schema_snippets[] = {
-	{ "", SNIPPET_LIST_NODES | SNIPPET_ALLOW_TEXT,
+	{ "any", SNIPPET_LIST_NODES | SNIPPET_ANY | SNIPPET_ALLOW_TEXT,
 		G_STRUCT_OFFSET(LassoSamlAttributeValue, any), NULL, NULL, NULL},
 	{NULL, 0, 0, NULL, NULL, NULL}
 };
