@@ -82,13 +82,13 @@ static LassoNodeClass *parent_class = NULL;
 /*****************************************************************************/
 
 static void
-instance_init(LassoSamlpRequestAbstract *node)
+instance_init(LassoSamlpRequestAbstract *node, G_GNUC_UNUSED void *unused)
 {
 	node->sign_type = LASSO_SIGNATURE_TYPE_NONE;
 }
 
 static void
-class_init(LassoSamlpRequestAbstractClass *klass)
+class_init(LassoSamlpRequestAbstractClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
