@@ -47,7 +47,7 @@ static struct XmlSnippet schema_snippets[] = {
 
 
 static void
-class_init(LassoSoapEnvelopeClass *klass)
+class_init(LassoSoapEnvelopeClass *klass, void *unused G_GNUC_UNUSED)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
