@@ -47,6 +47,7 @@
 #include <libxml/xmlIO.h>
 
 #include <openssl/evp.h>
+#include <openssl/pem.h>
 
 #include <xmlsec/base64.h>
 #include <xmlsec/crypto.h>
@@ -63,6 +64,7 @@
 #include <glib.h>
 #include "xml.h"
 #include "xml_enc.h"
+#include "../id-ff/server.h"
 #include "saml-2.0/saml2_assertion.h"
 #include <unistd.h>
 #include "../debug.h"
@@ -308,8 +310,13 @@ xmlSecKeyPtr lasso_get_public_key_from_pem_file(const char *file) {
 			pub_key = lasso_get_public_key_from_pem_cert_file(file);
 			break;
 		case LASSO_PEM_FILE_TYPE_PUB_KEY:
+#if LASSO_XMLSEC_VERSION_NUMBER >= 0x010300
+			pub_key = xmlSecCryptoAppKeyLoadEx(file, xmlSecKeyDataTypePublic | xmlSecKeyDataTypePrivate,
+					xmlSecKeyDataFormatPem, NULL, NULL, NULL);
+#else
 			pub_key = xmlSecCryptoAppKeyLoad(file,
 					xmlSecKeyDataFormatPem, NULL, NULL, NULL);
+#endif
 			break;
 		case LASSO_PEM_FILE_TYPE_PRIVATE_KEY:
 			pub_key = lasso_get_public_key_from_private_key_file(file);
@@ -377,8 +384,13 @@ lasso_get_public_key_from_pem_cert_file(const char *pem_cert_file)
 static xmlSecKeyPtr
 lasso_get_public_key_from_private_key_file(const char *private_key_file)
 {
+#if LASSO_XMLSEC_VERSION_NUMBER >= 0x010300
+	return xmlSecCryptoAppKeyLoadEx(private_key_file, xmlSecKeyDataTypePrivate | xmlSecKeyDataTypePublic,
+			xmlSecKeyDataFormatPem, NULL, NULL, NULL);
+#else
 	return xmlSecCryptoAppKeyLoad(private_key_file,
 			xmlSecKeyDataFormatPem, NULL, NULL, NULL);
+#endif
 }
 
 /**
@@ -1027,12 +1039,12 @@ lasso_saml2_query_verify_signature(const char *query, xmlSecKey *sender_public_k
 		goto_cleanup_with_rc(LASSO_PROFILE_ERROR_INVALID_QUERY);
 	}
 
-	if (! sig_alg) {
-		goto_cleanup_with_rc(LASSO_DS_ERROR_INVALID_SIGALG);
-	}
 	if (! b64_signature) {
 		goto_cleanup_with_rc(LASSO_DS_ERROR_SIGNATURE_NOT_FOUND);
 	}
+	if (! sig_alg) {
+		goto_cleanup_with_rc(LASSO_DS_ERROR_INVALID_SIGALG);
+	}
 	/* build the signed query */
 	if (relaystate) {
 		signed_query = g_strconcat(saml_request_response, "&", relaystate, "&", sig_alg, NULL);
@@ -1249,9 +1261,9 @@ cleanup:
 	if (doc) {
 		xmlRemoveID(doc, id_attr);
 		xmlUnlinkNode(xmlnode);
-		lasso_release_doc(doc);
 		xmlnode->parent = old_parent;
 		xmlSetTreeDoc(xmlnode, NULL);
+		lasso_release_doc(doc);
 	}
 	lasso_release_signature_context(dsig_ctx);
 	return rc;
@@ -1449,7 +1461,14 @@ lasso_concat_url_query(const char *url, const char *query)
 	}
 }
 
-static void structuredErrorFunc (void *userData, xmlErrorPtr error) {
+static void structuredErrorFunc (void *userData,
+#if LIBXML_VERSION >= 21200
+                                        const xmlError *error
+#else
+                                        xmlErrorPtr error
+#endif
+				 )
+{
 		*(int*)userData = error->code;
 }
 
@@ -2210,7 +2229,7 @@ lasso_xml_parse_memory_with_error(const char *buffer, int size, xmlError *error)
 		return NULL;
 	}
 	ctxt->recovery = 0;
-	xmlCtxtUseOptions(ctxt, XML_PARSE_NONET);
+	xmlCtxtUseOptions(ctxt, XML_PARSE_NONET | XML_PARSE_NOCDATA);
 	if (error) {
 		ctxt->sax->warning = NULL;
 		ctxt->sax->error = NULL;
@@ -2542,7 +2561,7 @@ lasso_base64_decode(const char *from, char **buffer, int *buffer_len)
 	xmlSecErrorsDefaultCallbackEnableOutput(TRUE);
 	if (ret == 0) {
 		out[outlen - 1] = 0;
-		lasso_transfer_string(*buffer, *((char**)&out));
+		lasso_transfer_string(*(xmlChar**)buffer, out);
 		*buffer_len = decodedlen;
 	} else {
 		rc = FALSE;
@@ -2554,7 +2573,7 @@ lasso_base64_decode(const char *from, char **buffer, int *buffer_len)
 
 	if (ret >= 0) {
 		out[outlen - 1] = 0;
-		lasso_transfer_string(*buffer, *((char**)&out));
+		lasso_transfer_string(*(xmlChar**)buffer, out);
 		*buffer_len = ret;
 	} else {
 		rc = FALSE;
@@ -2696,7 +2715,7 @@ cleanup:
 xmlSecKeyPtr
 lasso_xmlsec_load_key_info(xmlNode *key_descriptor)
 {
-	xmlSecKeyPtr key, result = NULL;
+	xmlSecKeyPtr key = NULL, result = NULL;
 	xmlNodePtr key_info = NULL;
 	xmlSecKeyInfoCtx ctx = {0};
 	xmlSecKeysMngr *keys_mngr = NULL;
@@ -2730,6 +2749,17 @@ lasso_xmlsec_load_key_info(xmlNode *key_descriptor)
 	ctx.keyReq.keyUsage = xmlSecKeyDataUsageAny;
 	ctx.certsVerificationDepth = 0;
 
+	if((xmlSecPtrListAdd(&ctx.enabledKeyData, BAD_CAST xmlSecKeyDataX509Id) < 0) ||
+		(xmlSecPtrListAdd(&ctx.enabledKeyData, BAD_CAST xmlSecKeyDataValueId) < 0) ||
+		(xmlSecPtrListAdd(&ctx.enabledKeyData, BAD_CAST xmlSecKeyDataRsaId) < 0) ||
+		(xmlSecPtrListAdd(&ctx.enabledKeyData, BAD_CAST xmlSecKeyDataDsaId) < 0) ||
+		(xmlSecPtrListAdd(&ctx.enabledKeyData, BAD_CAST xmlSecKeyDataHmacId) < 0)) {
+		message(G_LOG_LEVEL_CRITICAL, "Could not enable needed KeyData");
+		goto next;
+	}
+
+
+
 	key = xmlSecKeyCreate();
 	if (lasso_flag_pem_public_key) {
 		xmlSecErrorsDefaultCallbackEnableOutput(FALSE);
@@ -3126,7 +3156,7 @@ lasso_xmlnode_add_saml2_signature_template(xmlNode *node, LassoSignatureContext
 				break;
 			case LASSO_SIGNATURE_METHOD_RSA_SHA512:
 			case LASSO_SIGNATURE_METHOD_HMAC_SHA512:
-				digest_method_id = xmlSecTransformSha384Id;
+				digest_method_id = xmlSecTransformSha512Id;
 				break;
 			default:
 				g_assert_not_reached();
@@ -3226,6 +3256,17 @@ cleanup:
 	return saml_message;
 }
 
+static gboolean
+lasso_is_redirect_message(const char *message) {
+	if (lasso_strstartswith(message, LASSO_SAML2_FIELD_REQUEST "=") || lasso_strstartswith(message, LASSO_SAML2_FIELD_RESPONSE "=")) {
+		return TRUE;
+	}
+	if (strstr(message, "&" LASSO_SAML2_FIELD_REQUEST "=") || strstr(message, "&" LASSO_SAML2_FIELD_RESPONSE "=")) {
+		return TRUE;
+	}
+	return FALSE;
+}
+
 /**
  * lasso_xmltextreader_from_message:
  * @message: the HTTP query, POST content or SOAP message
@@ -3235,7 +3276,6 @@ cleanup:
 xmlTextReader *
 lasso_xmltextreader_from_message(const char *message, char **to_free) {
 	size_t len = strlen(message);
-	char *needle;
 	xmlChar **query_fields = NULL;
 	char *decoded_message = NULL;
 	int decoded_message_len = 0;
@@ -3244,9 +3284,8 @@ lasso_xmltextreader_from_message(const char *message, char **to_free) {
 	g_assert(to_free);
 	/* Differentiate SOAP from others */
 	if (message[0] != '<') {
-		needle = strchr(message, '=');
 		/* Differentiate redirect binding from POST */
-		if (needle && message[len-1] != '=') {
+		if (lasso_is_redirect_message(message)) {
 			query_fields = lasso_urlencoded_to_strings(message);
 			message = *to_free = lasso_get_saml_message(query_fields);
 			if (! message) {
