@@ -1581,7 +1581,7 @@ START_TEST(test12_ecp)
 }
 END_TEST
 
-void check_digest_method(G_GNUC_UNUSED LassoLogin *idp_login_context, LassoLogin *sp_login_context)
+void check_sha256_digest_method(G_GNUC_UNUSED LassoLogin *idp_login_context, LassoLogin *sp_login_context)
 {
 	char *dump = lasso_node_debug((LassoNode*)sp_login_context->parent.response, 10);
 	check_true(strstr(dump, "<DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha256\"/>") != NULL);
@@ -1604,7 +1604,7 @@ START_TEST(test13_sso_sp_with_rsa_sha256_signatures)
 	test07_make_context(sp_context, "sp6-saml2", LASSO_PROVIDER_ROLE_IDP, "idp6-saml2", key)
 
 	block_lasso_logs;
-	sso_initiated_by_sp(idp_context, sp_context, check_digest_method);
+	sso_initiated_by_sp(idp_context, sp_context, check_sha256_digest_method);
 	unblock_lasso_logs;
 
 	/* Cleanup */
@@ -1614,6 +1614,40 @@ START_TEST(test13_sso_sp_with_rsa_sha256_signatures)
 }
 END_TEST
 
+void check_sha512_digest_method(G_GNUC_UNUSED LassoLogin *idp_login_context, LassoLogin *sp_login_context)
+{
+	char *dump = lasso_node_debug((LassoNode*)sp_login_context->parent.response, 10);
+	check_true(strstr(dump, "<DigestMethod Algorithm=\"http://www.w3.org/2001/04/xmlenc#sha512\"/>") != NULL);
+	lasso_release_string(dump)
+}
+
+START_TEST(test14_sso_sp_with_rsa_sha512_signatures)
+{
+	LassoServer *idp_context = NULL;
+	LassoServer *sp_context = NULL;
+	GList *providers;
+	LassoKey *key = NULL;
+
+	/* Create a key for signature algorithm RSA_SHA256 */
+	key = lasso_key_new_for_signature_from_file(TESTSDATADIR "idp6-saml2/private-key.pem", NULL,
+			LASSO_SIGNATURE_METHOD_RSA_SHA512, NULL);
+	check_true(LASSO_IS_KEY(key));
+
+	test07_make_context(idp_context, "idp6-saml2", LASSO_PROVIDER_ROLE_SP, "sp6-saml2", key)
+	test07_make_context(sp_context, "sp6-saml2", LASSO_PROVIDER_ROLE_IDP, "idp6-saml2", key)
+
+	block_lasso_logs;
+	sso_initiated_by_sp(idp_context, sp_context, check_sha512_digest_method);
+	unblock_lasso_logs;
+
+	/* Cleanup */
+	lasso_release_gobject(idp_context);
+	lasso_release_gobject(sp_context);
+	lasso_release_gobject(key);
+}
+END_TEST
+
+
 Suite*
 login_saml2_suite()
 {
@@ -1647,6 +1681,7 @@ login_saml2_suite()
 	tcase_add_test(tc_ecp, test11_ecp);
 	tcase_add_test(tc_ecp, test12_ecp);
 	tcase_add_test(tc_spLogin, test13_sso_sp_with_rsa_sha256_signatures);
+	tcase_add_test(tc_spLogin, test14_sso_sp_with_rsa_sha512_signatures);
 	return s;
 }
 
