@@ -2,7 +2,6 @@ import sys
 import os.path
 sys.path.append(os.path.join(os.path.dirname(__file__),'../bindings'))
 import bindings
-from six import print_
 
 
 def main(args):
@@ -29,16 +28,16 @@ def main(args):
     l = sorted(d.keys())
     for x in l:
         if isinstance(d[x], bindings.Function):
-            print_(d[x].return_type, " ",)
-            print_(x, end='')
-            print_('(', ', '.join(map(lambda x: x[0] + ' ' + x[1], d[x].args)), ')')
+            print(d[x].return_type, " ",)
+            print(x, end='')
+            print('(', ', '.join(map(lambda x: x[0] + ' ' + x[1], d[x].args)), ')')
         elif isinstance(d[x], bindings.Struct):
-            print_('struct', x, '{ ',)
-            print_(', '.join(map(lambda x: x[0] + ' ' + x[1], d[x].members)),
+            print('struct', x, '{ ',)
+            print(', '.join(map(lambda x: x[0] + ' ' + x[1], d[x].members)),
                    end='')
-            print_(' }')
+            print(' }')
         else:
-            print_(x)
+            print(x)
 
 if __name__ == "__main__":
     main(sys.argv)
