@@ -3,10 +3,9 @@
 import sys
 import os.path
 import re
-from six import print_
 
 if len(sys.argv) < 3:
-    print_("Usage: check-lasso-sections.py "
+    print("Usage: check-lasso-sections.py "
            "lasso docs/referenrece/lasso/lasso-sections.txt",
            file=sys.stderr)
     sys.exit(1)
@@ -34,13 +33,13 @@ for dirpath, dirnames, filenames in os.walk(source):
 
 lasso_sections_txt=file(lasso_sections_txt).read()
 
-print_(' = Methods missing from lasso-sections.txt =\n')
+print(' = Methods missing from lasso-sections.txt =\n')
 for method in methods:
     if not method in lasso_sections_txt:
-        print_(method)
+        print(method)
 
-print_(' = Methods in lasso-sections.txt which does not exist anymore = \n')
+print(' = Methods in lasso-sections.txt which does not exist anymore = \n')
 for line in lasso_sections_txt.splitlines():
     if line.startswith('lasso_'):
         if line not in methods:
-            print_(line)
+            print(line)
