@@ -1,7 +1,6 @@
 import re
-from six import print_
 
-valgrind_log = open('log','r').read()
+valgrind_log = open('log').read()
 
 inblock = False
 l = 0
@@ -34,11 +33,11 @@ for line in valgrind_log.splitlines():
 i = 43
 for x in keep:
     block = keep[x]
-    print_("{")
-    print_("   suppression", i)
+    print("{")
+    print("   suppression", i)
     for x in block[1:]:
-        print_(x)
+        print(x)
         if re.search(limit_re, x):
             break
-    print_('}')
+    print('}')
     i += 1
